#[non_exhaustive]pub struct AdminAnalyticsGetFileRequest {
pub type: String,
pub date: Option<String>,
pub metadata_only: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.analytics.getFile: Retrieve analytics data for a given date, presented as a compressed JSON file
Send it with SlackClient::admin_analytics_get_file.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: StringThe type of analytics to retrieve. The options are currently limited to member (for Enterprise org member analytics) and public_channel (for public channel analytics).
date: Option<String>Date to retrieve the analytics data for, expressed as YYYY-MM-DD in UTC. Required unless metadata_only is set to true.
metadata_only: Option<bool>Retrieve metadata for the type of analytics indicated. Can be used only with type set to public_channel analytics. See detail below. Omit the date parameter when using this argument.
Implementations