AdminAnalyticsMessagesActivityRequest

Struct AdminAnalyticsMessagesActivityRequest 

#[non_exhaustive]
pub struct AdminAnalyticsMessagesActivityRequest { pub channel: String, pub oldest_ts: Option<String>, pub latest_ts: Option<String>, pub cursor: Option<String>, pub limit: Option<i64>, }
Arguments for the Slack Web API method admin.analytics.messages.activity: Retrieves activity metrics for messages from a given channel.

Send it with SlackClient::admin_analytics_messages_activity.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
channel: String

Channel ID for channel of the message activity to query.

oldest_ts: Option<String>

Oldest timestamp to include in the results. Defaults to 7 days before current time. If not passed while still passing the latest_ts parameter, defaults to 7 days before latest_ts.

latest_ts: Option<String>

Most recent timestamp to include in results. Defaults to current time. If not passed while still passing the oldest_ts parameter, defaults to 7 days after oldest_ts.

cursor: Option<String>

Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection.

limit: Option<i64>

Maximum number of entries to return. Defaults to 50 if not passed. Max allowed is 100.

Implementations

Source

impl AdminAnalyticsMessagesActivityRequest

pub fn new(channel: impl Into<String>) -> Self

pub fn oldest_ts(self, oldest_ts: impl Into<String>) -> Self

pub fn latest_ts(self, latest_ts: impl Into<String>) -> Self

pub fn cursor(self, cursor: impl Into<String>) -> Self

pub fn limit(self, limit: i64) -> Self