#[non_exhaustive]pub struct AdminAnalyticsMessagesMetadataRequest {
pub channel: String,
pub oldest_ts: Option<String>,
pub latest_ts: Option<String>,
pub cursor: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.analytics.messages.metadata: Retrieves metadata for a list of messages from a given channel.
Send it with SlackClient::admin_analytics_messages_metadata.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel ID for channel containing the messages to query.
oldest_ts: Option<String>Oldest timestamp to include in the results
latest_ts: Option<String>Most recent timestamp to include in the results. If not passed, defaults to current time.
cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.
Implementations