AdminAppsActivitiesListRequest

Struct AdminAppsActivitiesListRequest 

#[non_exhaustive]
pub struct AdminAppsActivitiesListRequest {
Show 13 fields pub app_id: Option<String>, pub team_id: Option<String>, pub cursor: Option<String>, pub limit: Option<i64>, pub min_log_level: Option<String>, pub log_event_type: Option<String>, pub source: Option<String>, pub component_type: Option<String>, pub component_id: Option<String>, pub trace_id: Option<String>, pub min_date_created: Option<i64>, pub max_date_created: Option<i64>, pub sort_direction: Option<String>,
}
Arguments for the Slack Web API method admin.apps.activities.list: Get logs for a specified team/org

Send it with SlackClient::admin_apps_activities_list.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
app_id: Option<String>

The ID of the app to get activities from.

team_id: Option<String>

The team who owns this log.

cursor: Option<String>

Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. See pagination for more detail.

limit: Option<i64>

The maximum number of items to return.

min_log_level: Option<String>

The minimum log level of the log events to be returned. Defaults to info. Acceptable values (in order of relative importance from smallest to largest) are trace, debug, info, warn, error and fatal.

log_event_type: Option<String>

The event type of log events to be returned.

source: Option<String>

The source of log events to be returned. Acceptable values are slack and developer.

component_type: Option<String>

The component type of log events to be returned. Acceptable values are events_api, workflows, functions and tables.

component_id: Option<String>

The component ID of log events to be returned. Will be FnXXXXXX for functions, and WfXXXXXX for workflows

trace_id: Option<String>

The trace ID of log events to be returned.

min_date_created: Option<i64>

The earliest timestamp of the log to retrieve (epoch microseconds).

max_date_created: Option<i64>

The latest timestamp of the log to retrieve (epoch microseconds).

sort_direction: Option<String>

The direction you want the data sorted by (always by timestamp)

Implementations

Source

impl AdminAppsActivitiesListRequest

pub fn new() -> Self

pub fn app_id(self, app_id: impl Into<String>) -> Self

pub fn team_id(self, team_id: impl Into<String>) -> Self

pub fn cursor(self, cursor: impl Into<String>) -> Self

pub fn limit(self, limit: i64) -> Self

pub fn min_log_level(self, min_log_level: impl Into<String>) -> Self

pub fn log_event_type(self, log_event_type: impl Into<String>) -> Self

pub fn source(self, source: impl Into<String>) -> Self

pub fn component_type(self, component_type: impl Into<String>) -> Self

pub fn component_id(self, component_id: impl Into<String>) -> Self

pub fn trace_id(self, trace_id: impl Into<String>) -> Self

pub fn min_date_created(self, min_date_created: i64) -> Self

pub fn max_date_created(self, max_date_created: i64) -> Self

pub fn sort_direction(self, sort_direction: impl Into<String>) -> Self