#[non_exhaustive]pub struct AdminAppsApproveRequest {
pub allow_child_auto_install: Option<bool>,
pub app_id: Option<String>,
pub request_id: Option<String>,
pub team_id: Option<String>,
pub enterprise_id: Option<String>,
pub user_scopes: Option<String>,
pub bot_scopes: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.apps.approve: Approve an app for installation on a workspace.
Send it with SlackClient::admin_apps_approve.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.allow_child_auto_install: Option<bool>Auto-create an Admin-Approved App automation rule that pre-approves future child app installs from this manager app.
app_id: Option<String>The id of the app to approve.
request_id: Option<String>The id of the request to approve.
team_id: Option<String>The ID of the workspace to approve the app on
enterprise_id: Option<String>The ID of the enterprise to approve the app on
user_scopes: Option<String>User scopes to approve for the app
bot_scopes: Option<String>Bot scopes to approve for the app
Implementations
Sourceimpl AdminAppsApproveRequest
impl AdminAppsApproveRequest
pub fn new() -> Self
pub fn allow_child_auto_install(self, allow_child_auto_install: bool) -> Self
pub fn app_id(self, app_id: impl Into<String>) -> Self
pub fn request_id(self, request_id: impl Into<String>) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self
pub fn enterprise_id(self, enterprise_id: impl Into<String>) -> Self
pub fn user_scopes(self, user_scopes: impl Into<String>) -> Self
pub fn bot_scopes(self, bot_scopes: impl Into<String>) -> Self