#[non_exhaustive]pub struct AdminAppsApprovedListRequest {
pub limit: Option<i64>,
pub cursor: Option<String>,
pub team_id: Option<String>,
pub enterprise_id: Option<String>,
pub certified: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.apps.approved.list: List approved apps for an org or workspace.
Send it with SlackClient::admin_apps_approved_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.limit: Option<i64>The maximum number of items to return. Must be between 1 - 1000 both inclusive.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page
team_id: Option<String>enterprise_id: Option<String>certified: Option<bool>Limit the results to only include certified apps. When false, no certified apps will appear in the result
Implementations
Sourceimpl AdminAppsApprovedListRequest
impl AdminAppsApprovedListRequest
pub fn new() -> Self
pub fn limit(self, limit: i64) -> Self
pub fn cursor(self, cursor: impl Into<String>) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self
pub fn enterprise_id(self, enterprise_id: impl Into<String>) -> Self
pub fn certified(self, certified: bool) -> Self