#[non_exhaustive]pub struct AdminAppsConfigLookupRequest {
pub app_ids: Option<Vec<String>>,
pub rich_link_preview_types: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method admin.apps.config.lookup: Look up the app config for connectors by their IDs
Send it with SlackClient::admin_apps_config_lookup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_ids: Option<Vec<String>>An array of app IDs to get app configs for
rich_link_preview_types: Option<Vec<String>>return apps with the corresponding rich link preview layouts
Implementations