#[non_exhaustive]pub struct AdminAppsPermissionsSetRequest {
pub app_id: String,
pub permission_type: String,
pub user_ids: Option<Vec<String>>,
pub usergroup_ids: Option<Vec<String>>,
pub channel_restriction_mode: Option<String>,
pub channel_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method admin.apps.permissions.set: Set the permission type for who can access an app.
Send it with SlackClient::admin_apps_permissions_set.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_id: StringEncoded ID of the app
permission_type: StringThe type of permission that defines who can access the app
user_ids: Option<Vec<String>>List of user IDs to allow for named_entities visibility
usergroup_ids: Option<Vec<String>>List of encoded usergroup IDs
channel_restriction_mode: Option<String>The mode that defines where the app can be used in channels
channel_ids: Option<Vec<String>>List of encoded channel IDs for channel restrictions. Semantics depend on channel_restriction_mode: allowlist for specific_channels, exclusion list for all_channels_except
Implementations
Sourceimpl AdminAppsPermissionsSetRequest
impl AdminAppsPermissionsSetRequest
pub fn new( app_id: impl Into<String>, permission_type: impl Into<String>, ) -> Self
pub fn user_ids(self, user_ids: Vec<String>) -> Self
pub fn usergroup_ids(self, usergroup_ids: Vec<String>) -> Self
pub fn channel_restriction_mode( self, channel_restriction_mode: impl Into<String>, ) -> Self
pub fn channel_ids(self, channel_ids: Vec<String>) -> Self