#[non_exhaustive]pub struct AdminAppsUninstallRequest {
pub app_id: String,
pub team_ids: Option<String>,
pub enterprise_id: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.apps.uninstall: Uninstall an app from one or many workspaces, or an entire enterprise organization.
Send it with SlackClient::admin_apps_uninstall.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_id: StringThe ID of the app to uninstall.
team_ids: Option<String>IDs of the teams to uninstall from (max 100). With an org-level token, this or enterprise_id is required.
enterprise_id: Option<String>The enterprise to completely uninstall the application from (across all workspaces). With an org-level token, this or team_ids is required.
Implementations