#[non_exhaustive]pub struct AdminAuthPolicyAssignEntitiesRequest {
pub policy_name: String,
pub entity_type: String,
pub entity_ids: Vec<String>,
}Expand description
Arguments for the Slack Web API method admin.auth.policy.assignEntities: Assign entities to a particular authentication policy.
Send it with SlackClient::admin_auth_policy_assign_entities.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_name: StringThe name of the authentication policy to assign the entities to. Currently, email_password is the only policy that may be used with this method.
entity_type: StringThe type of entity to assign to the policy. Currently, USER is supported.
entity_ids: Vec<String>Array of IDs to assign to the policy.
Implementations