#[non_exhaustive]pub struct AdminAuthPolicyGetEntitiesRequest {
pub policy_name: String,
pub entity_type: Option<String>,
pub limit: Option<i64>,
pub cursor: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.auth.policy.getEntities: Fetch all the entities assigned to a particular authentication policy by name.
Send it with SlackClient::admin_auth_policy_get_entities.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_name: StringThe name of the policy to fetch entities for. Currently, email_password is the only policy that may be used with this method.
entity_type: Option<String>The type of entity to assign to the policy. Currently, USER is supported.
limit: Option<i64>The maximum number of items to return. Must be between 1 and 1000, both inclusive.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page.
Implementations