#[non_exhaustive]pub struct AdminAuthPolicyRemoveEntitiesRequest {
pub policy_name: String,
pub entity_type: String,
pub entity_ids: Vec<String>,
}Expand description
Arguments for the Slack Web API method admin.auth.policy.removeEntities: Remove specified entities from a specified authentication policy.
Send it with SlackClient::admin_auth_policy_remove_entities.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_name: StringThe name of the policy to remove entities from. Currently, email_password is the only policy that may be used with this method.
entity_type: StringThe type of entity to assign to the policy. Currently, USER is supported.
entity_ids: Vec<String>Encoded IDs of the entities you’d like to remove from the policy.
Implementations