#[non_exhaustive]pub struct AdminBarriersUpdateRequest {
pub barrier_id: String,
pub primary_usergroup_id: String,
pub barriered_from_usergroup_ids: Vec<String>,
pub restricted_subjects: Vec<Value>,
}Expand description
Arguments for the Slack Web API method admin.barriers.update: Update an existing Information Barrier
Send it with SlackClient::admin_barriers_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.barrier_id: StringThe ID of the barrier you’re trying to modify
primary_usergroup_id: StringThe id of the primary IDP Group
barriered_from_usergroup_ids: Vec<String>A list of IDP Groups ids that the primary usergroup is to be barriered from.
restricted_subjects: Vec<Value>What kind of interactions are blocked by this barrier? For v1, we only support a list of all 3, eg im, mpim, call
Implementations