#[non_exhaustive]pub struct AdminConversationsBulkSetPropertiesRequest {
pub channel_ids: Vec<String>,
pub property: String,
}Expand description
Arguments for the Slack Web API method admin.conversations.bulkSetProperties: Set properties on channels in bulk
Send it with SlackClient::admin_conversations_bulk_set_properties.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_ids: Vec<String>An array of channel IDs on which to set the property.
property: StringThe property for this channel in a key value format. Only one property can be updated at a time
Implementations