#[non_exhaustive]pub struct AdminConversationsCreateForObjectsRequest {
pub object_id: String,
pub salesforce_org_id: String,
pub invite_object_team: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.conversations.createForObjects: Create a Salesforce channel for the corresponding object provided.
Send it with SlackClient::admin_conversations_create_for_objects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.object_id: StringObject / Record ID (15 or 18 digit accepted). See here for how to look up an ID.
salesforce_org_id: StringSalesforce org ID (15 or 18 digit accepted). See here for how to look up Salesforce org ID.
invite_object_team: Option<bool>Optional flag to add all team members related to the object to the newly created Salesforce channel. When true, adds a maximum of 100 team members to the channel.
Implementations