#[non_exhaustive]pub struct AdminConversationsCreateRequest {
pub name: String,
pub is_private: bool,
pub description: Option<String>,
pub org_wide: Option<bool>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.conversations.create: Create a public or private channel-based conversation.
Send it with SlackClient::admin_conversations_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the public or private channel to create.
is_private: boolWhen true, creates a private channel instead of a public channel
description: Option<String>Description of the public or private channel to create.
org_wide: Option<bool>When true, the channel will be available org-wide. Note: if the channel is not org_wide=true, you must specify a team_id for this channel
team_id: Option<String>The workspace to create the channel in. Note: this argument is required unless you set org_wide=true.
Implementations