#[non_exhaustive]pub struct AdminConversationsDisconnectSharedRequest {
pub channel_id: String,
pub leaving_team_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method admin.conversations.disconnectShared: Disconnect a connected channel from one or more workspaces.
Send it with SlackClient::admin_conversations_disconnect_shared.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringThe channel to be disconnected from some workspaces.
leaving_team_ids: Option<Vec<String>>Used for disconnecting a team from a shared channel. Only one team ID may be passed at a time.
Implementations