#[non_exhaustive]pub struct AdminConversationsEkmListOriginalConnectedChannelInfoRequest {
pub channel_ids: Option<String>,
pub team_ids: Option<String>,
pub limit: Option<i64>,
pub cursor: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.conversations.ekm.listOriginalConnectedChannelInfo: List all disconnected channels—i.e., channels that were once connected to other workspaces and then disconnected—and the corresponding original channel IDs for key revocation with EKM.
Send it with SlackClient::admin_conversations_ekm_list_original_connected_channel_info.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_ids: Option<String>A comma-separated list of channels to filter to.
team_ids: Option<String>A comma-separated list of the workspaces to which the channels you would like returned belong.
limit: Option<i64>The maximum number of items to return. Must be between 1 - 1000 both inclusive.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page.
Implementations