#[non_exhaustive]pub struct AdminConversationsGetTeamsRequest {
pub channel_id: String,
pub cursor: Option<String>,
pub limit: Option<i64>,
}Expand description
Arguments for the Slack Web API method admin.conversations.getTeams: Get all the workspaces a given public or private channel is connected to within this Enterprise org.
Send it with SlackClient::admin_conversations_get_teams.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringThe channel to determine connected workspaces within the organization for.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page
limit: Option<i64>The maximum number of items to return. Must be between 1 - 1000 both inclusive.
Implementations