#[non_exhaustive]pub struct AdminConversationsInviteRequest {
pub user_ids: Vec<String>,
pub channel_id: String,
}Expand description
Arguments for the Slack Web API method admin.conversations.invite: Invite a user to a public or private channel.
Send it with SlackClient::admin_conversations_invite.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_ids: Vec<String>The users to invite.
channel_id: StringThe channel that the users will be invited to.
Implementations