#[non_exhaustive]pub struct AdminConversationsLinkObjectsRequest {
pub channel: String,
pub record_id: String,
pub salesforce_org_id: String,
}Expand description
Arguments for the Slack Web API method admin.conversations.linkObjects: Link a Salesforce record to a channel
Send it with SlackClient::admin_conversations_link_objects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel ID for Slack channel that will be linked to a Salesforce record.
record_id: StringSalesforce record ID (15 or 18 digit accepted). See here for how to look up record ID.
salesforce_org_id: StringSalesforce org ID (15 or 18 digit accepted). See here for how to look up Salesforce org ID.
Implementations