#[non_exhaustive]pub struct AdminConversationsLookupRequest {
pub team_ids: Vec<String>,
pub last_message_activity_before: i64,
pub max_member_count: Option<i64>,
pub cursor: Option<String>,
pub limit: Option<i64>,
}Expand description
Arguments for the Slack Web API method admin.conversations.lookup: Returns channels on the given team using the filters.
Send it with SlackClient::admin_conversations_lookup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_ids: Vec<String>Array of team IDs to filter by
last_message_activity_before: i64Filter by public channels where the most recent message was sent before last_message_activity
max_member_count: Option<i64>Filter by public channels with member count equal to or less than the specified number
cursor: Option<String>Set cursor to next_cursor returned in the previous call, to fetch the next page.
limit: Option<i64>Maximum number of results
Implementations