#[non_exhaustive]pub struct AdminConversationsRestrictAccessAddGroupRequest {
pub group_id: String,
pub channel_id: String,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.conversations.restrictAccess.addGroup: Add an allowlist of IDP groups for accessing a channel
Send it with SlackClient::admin_conversations_restrict_access_add_group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group_id: StringThe IDP Group ID to be an allowlist for the private channel.
channel_id: StringThe channel to link this group to.
team_id: Option<String>The workspace where the channel exists. This argument is required for channels only tied to one workspace, and optional for channels that are shared across an organization.
Implementations