AdminConversationsRestrictAccessListGroupsRequest

Struct AdminConversationsRestrictAccessListGroupsRequest 

#[non_exhaustive]
pub struct AdminConversationsRestrictAccessListGroupsRequest { pub channel_id: String, pub team_id: Option<String>, }
Arguments for the Slack Web API method admin.conversations.restrictAccess.listGroups: List all IDP Groups linked to a channel

Send it with SlackClient::admin_conversations_restrict_access_list_groups.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
channel_id: Stringteam_id: Option<String>

The workspace where the channel exists. This argument is required for channels only tied to one workspace, and optional for channels that are shared across an organization.

Implementations

Source

impl AdminConversationsRestrictAccessListGroupsRequest

pub fn new(channel_id: impl Into<String>) -> Self

pub fn team_id(self, team_id: impl Into<String>) -> Self