#[non_exhaustive]pub struct AdminConversationsRestrictAccessRemoveGroupRequest {
pub team_id: String,
pub group_id: String,
pub channel_id: String,
}Expand description
Arguments for the Slack Web API method admin.conversations.restrictAccess.removeGroup: Remove a linked IDP group linked from a private channel
Send it with SlackClient::admin_conversations_restrict_access_remove_group.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: StringThe workspace where the channel exists. This argument is required for channels only tied to one workspace, and optional for channels that are shared across an organization.
group_id: StringThe IDP Group ID to remove from the private channel.
channel_id: StringThe channel to remove the linked group from.
Implementations