AdminConversationsSearchRequest

Struct AdminConversationsSearchRequest 

#[non_exhaustive]
pub struct AdminConversationsSearchRequest { pub team_ids: Option<Vec<String>>, pub connected_team_ids: Option<Vec<String>>, pub query: Option<String>, pub limit: Option<i64>, pub cursor: Option<String>, pub search_channel_types: Option<Vec<String>>, pub sort: Option<String>, pub sort_dir: Option<String>, pub total_count_only: Option<bool>, }
Arguments for the Slack Web API method admin.conversations.search: Search for public or private channels in an Enterprise organization.

Send it with SlackClient::admin_conversations_search.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
team_ids: Option<Vec<String>>

Comma separated string of team IDs, signifying the internal workspaces to search through.

connected_team_ids: Option<Vec<String>>

Array of encoded team IDs, signifying the external orgs to search through.

query: Option<String>

Name of the the channel to query by.

limit: Option<i64>

Maximum number of items to be returned. Must be between 1 - 20 both inclusive. Default is 10.

cursor: Option<String>

Set cursor to next_cursor returned by the previous call to list items in the next page.

search_channel_types: Option<Vec<String>>

The type of channel to include or exclude in the search. For example private will search private channels, while private_exclude will exclude them. For a full list of types, check the Types section.

sort: Option<String>

Possible values are relevant (search ranking based on what we think is closest), name (alphabetical), member_count (number of users in the channel), and created (date channel was created). You can optionally pair this with the sort_dir arg to change how it is sorted

sort_dir: Option<String>

Sort direction. Possible values are asc for ascending order like (1, 2, 3) or (a, b, c), and desc for descending order like (3, 2, 1) or (c, b, a)

total_count_only: Option<bool>

Only return the total_count of channels. Omits channel data and allows access for admins without channel manager permissions.

Implementations

Source

impl AdminConversationsSearchRequest

pub fn new() -> Self

pub fn team_ids(self, team_ids: Vec<String>) -> Self

pub fn connected_team_ids(self, connected_team_ids: Vec<String>) -> Self

pub fn query(self, query: impl Into<String>) -> Self

pub fn limit(self, limit: i64) -> Self

pub fn cursor(self, cursor: impl Into<String>) -> Self

pub fn search_channel_types(self, search_channel_types: Vec<String>) -> Self

pub fn sort(self, sort: impl Into<String>) -> Self

pub fn sort_dir(self, sort_dir: impl Into<String>) -> Self

pub fn total_count_only(self, total_count_only: bool) -> Self