#[non_exhaustive]pub struct AdminConversationsSetConversationPrefsRequest {
pub channel_id: String,
pub prefs: String,
}Expand description
Arguments for the Slack Web API method admin.conversations.setConversationPrefs: Set the posting permissions for a public or private channel.
Send it with SlackClient::admin_conversations_set_conversation_prefs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringThe channel to set the prefs for
prefs: StringThe prefs for this channel in a stringified JSON format.
Implementations