#[non_exhaustive]pub struct AdminConversationsSetCustomRetentionRequest {
pub channel_id: String,
pub duration_days: i64,
}Expand description
Arguments for the Slack Web API method admin.conversations.setCustomRetention: This API endpoint can be used by any admin to set a conversation’s retention policy.
Send it with SlackClient::admin_conversations_set_custom_retention.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringThe conversation to set the retention policy for.
duration_days: i64The message retention duration in days to set for this conversation
Implementations