#[non_exhaustive]pub struct AdminConversationsSetTeamsRequest {
pub channel_id: String,
pub team_id: Option<String>,
pub target_team_ids: Option<Vec<String>>,
pub org_channel: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.conversations.setTeams: Set the workspaces in an Enterprise org that connect to a public or private channel.
Send it with SlackClient::admin_conversations_set_teams.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringThe encoded channel_id to add or remove to workspaces.
team_id: Option<String>The workspace to which the channel belongs if the channel is a local workspace channel. Omit this argument if the channel is a cross-workspace or org-wide shared channel.
target_team_ids: Option<Vec<String>>A comma-separated list of workspaces to which the channel should be shared. Not required if the channel is being shared org-wide.
org_channel: Option<bool>True if channel has to be converted to an org channel
Implementations