#[non_exhaustive]pub struct AdminConversationsUnlinkObjectsRequest {
pub channel: String,
pub new_name: String,
}Expand description
Arguments for the Slack Web API method admin.conversations.unlinkObjects: Unlink a Salesforce record from a channel
Send it with SlackClient::admin_conversations_unlink_objects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel ID for Slack channel that will be unlinked from the Salesforce record.
new_name: StringChannel name you would like to give to the channel that is being unlinked from the Salesforce record.
Implementations