#[non_exhaustive]pub struct AdminEmojiAddAliasRequest {
pub name: String,
pub alias_for: String,
}Expand description
Arguments for the Slack Web API method admin.emoji.addAlias: Add an emoji alias.
Send it with SlackClient::admin_emoji_add_alias.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe new alias for the specified emoji. Any wrapping whitespace or colons will be automatically trimmed.
alias_for: StringName of the emoji for which the alias is being made. Any wrapping whitespace or colons will be automatically trimmed.
Implementations