#[non_exhaustive]pub struct AdminEmojiAddRequest {
pub name: String,
pub url: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.emoji.add: Add an emoji.
Send it with SlackClient::admin_emoji_add.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the emoji to be added (using lower-case letters only). Colons (:myemoji:) around the value are not required, although they may be included.
url: Option<String>The URL of a file to use as an image for the emoji. Square images under 128KB and with transparent backgrounds work best.
Implementations