AdminFunctionsListRequest

Struct AdminFunctionsListRequest 

#[non_exhaustive]
pub struct AdminFunctionsListRequest { pub app_ids: Vec<String>, pub team_id: Option<String>, pub include_non_distributed_functions: Option<bool>, pub cursor: Option<String>, pub limit: Option<i64>, }
Arguments for the Slack Web API method admin.functions.list: Look up functions by a set of apps.

Send it with SlackClient::admin_functions_list.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
app_ids: Vec<String>

Comma-separated array of app IDs to get functions for; max 50.

team_id: Option<String>

The team context to retrieve functions from.

include_non_distributed_functions: Option<bool>

Whether to also include functions that are not yet distributed to any users in the function list. This is needed for admins that are approving an app request and will only work if the team owns the app.

cursor: Option<String>

Set cursor to next_cursor returned by the previous call to list items in the next page.

limit: Option<i64>

The number of results that will be returned by the API on each invocation. Must be between 1 and 1000, both inclusive.

Implementations

Source

impl AdminFunctionsListRequest

pub fn new(app_ids: Vec<String>) -> Self

pub fn team_id(self, team_id: impl Into<String>) -> Self

pub fn include_non_distributed_functions( self, include_non_distributed_functions: bool, ) -> Self

pub fn cursor(self, cursor: impl Into<String>) -> Self

pub fn limit(self, limit: i64) -> Self