#[non_exhaustive]pub struct AdminFunctionsPermissionsLookupRequest {
pub function_ids: Vec<String>,
}Expand description
Arguments for the Slack Web API method admin.functions.permissions.lookup: Lookup the visibility of multiple Slack functions and include the users if it is limited to particular named entities.
Send it with SlackClient::admin_functions_permissions_lookup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.function_ids: Vec<String>An array of function IDs to get permissions for
Implementations