#[non_exhaustive]pub struct AdminInviteRequestsDeniedListRequest {
pub team_id: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i64>,
}Expand description
Arguments for the Slack Web API method admin.inviteRequests.denied.list: List all denied workspace invite requests.
Send it with SlackClient::admin_invite_requests_denied_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: Option<String>ID for the workspace where the invite requests were made
cursor: Option<String>Value of the next_cursor field sent as part of the previous api response
limit: Option<i64>The number of results that will be returned by the API on each invocation. Must be between 1 - 1000 both inclusive
Implementations