#[non_exhaustive]pub struct AdminRolesListAssignmentsRequest {
pub cursor: Option<String>,
pub limit: Option<i64>,
pub role_ids: Option<Vec<String>>,
pub entity_ids: Option<Vec<String>>,
pub sort_dir: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.roles.listAssignments: Lists assignments for all roles across entities. Options to scope results by any combination of roles or entities
Send it with SlackClient::admin_roles_list_assignments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page
limit: Option<i64>The maximum number of items to return. Must be between 1 - 200 both inclusive.
role_ids: Option<Vec<String>>collection of role ids to scope results by
entity_ids: Option<Vec<String>>The entities for which the roles apply
sort_dir: Option<String>Sort direction. Default is descending on date_create, can be either ASC or DESC
Implementations
Sourceimpl AdminRolesListAssignmentsRequest
impl AdminRolesListAssignmentsRequest
pub fn new() -> Self
pub fn cursor(self, cursor: impl Into<String>) -> Self
pub fn limit(self, limit: i64) -> Self
pub fn role_ids(self, role_ids: Vec<String>) -> Self
pub fn entity_ids(self, entity_ids: Vec<String>) -> Self
pub fn sort_dir(self, sort_dir: impl Into<String>) -> Self