#[non_exhaustive]pub struct AdminRolesRemoveAssignmentsRequest {
pub role_id: String,
pub entity_ids: Vec<String>,
pub user_ids: Vec<String>,
}Expand description
Arguments for the Slack Web API method admin.roles.removeAssignments: Removes a set of users from a role for the given scopes and entities
Send it with SlackClient::admin_roles_remove_assignments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role_id: StringID of the role to which users will be assigned
entity_ids: Vec<String>List of the entity IDs for which roles will be revoked. These can be Org IDs, Team IDs or Channel IDs
user_ids: Vec<String>List of IDs of the users whose roles will be revoked
Implementations