#[non_exhaustive]pub struct AdminTeamsListRequest {
pub limit: Option<i64>,
pub cursor: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.teams.list: List all teams in an Enterprise organization
Send it with SlackClient::admin_teams_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.limit: Option<i64>The maximum number of items to return. Must be a positive integer no larger than 1000.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page.
Implementations