#[non_exhaustive]pub struct AdminTeamsOwnersListRequest {
pub team_id: String,
pub limit: Option<i64>,
pub cursor: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.teams.owners.list: List all of the owners on a given workspace.
Send it with SlackClient::admin_teams_owners_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: Stringlimit: Option<i64>The maximum number of items to return. Must be between 1 - 1000 both inclusive.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page.
Implementations