#[non_exhaustive]pub struct AdminTeamsSettingsSetDiscoverabilityRequest {
pub team_id: String,
pub discoverability: String,
}Expand description
Arguments for the Slack Web API method admin.teams.settings.setDiscoverability: An API method that allows admins to set the discoverability of a given workspace
Send it with SlackClient::admin_teams_settings_set_discoverability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: StringThe ID of the workspace to set discoverability on.
discoverability: StringThis workspace’s discovery setting. It must be set to one of open, invite_only, closed, or unlisted.
Implementations