#[non_exhaustive]pub struct AdminUsergroupsAddTeamsRequest {
pub usergroup_id: String,
pub team_ids: Vec<String>,
pub auto_provision: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.usergroups.addTeams: Associate one or more default workspaces with an organization-wide IDP group.
Send it with SlackClient::admin_usergroups_add_teams.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.usergroup_id: StringAn encoded usergroup (IDP Group) ID.
team_ids: Vec<String>A comma separated list of encoded team (workspace) IDs. Each workspace MUST belong to the organization associated with the token.
auto_provision: Option<bool>When true, this method automatically creates new workspace accounts for the IDP group members.
Implementations