#[non_exhaustive]pub struct AdminUsergroupsCreateRequest {
pub name: String,
pub handle: Option<String>,
pub purpose: Option<String>,
pub is_visible: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.usergroups.create: Create a new organizational usergroup.
Send it with SlackClient::admin_usergroups_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringUnique name for the usergroup
handle: Option<String>Optional handle used to mention the usergroup in channel, must be unique
purpose: Option<String>Optional purpose that describes what the usergroup is about
is_visible: Option<bool>Configure whether or not this usergroup should be visible in the client
Implementations