#[non_exhaustive]pub struct AdminUsergroupsRemoveTeamsRequest {
pub usergroup_id: String,
pub team_ids: Vec<String>,
}Expand description
Arguments for the Slack Web API method admin.usergroups.removeTeams: Remove one or more default workspaces from an organization-wide IDP Group or Admin Group
Send it with SlackClient::admin_usergroups_remove_teams.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.usergroup_id: StringAn encoded usergroup (IDP Group) ID.
team_ids: Vec<String>A comma separated list of encoded team (workspace) IDs. Each workspace MUST belong to the organization associated with the token.
Implementations