#[non_exhaustive]pub struct AdminUsergroupsUpdateRequest {
pub id: String,
pub name: Option<String>,
pub handle: Option<String>,
pub description: Option<String>,
pub is_visible: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.usergroups.update: Update one or more properties of an existing organizational usergroup.
Send it with SlackClient::admin_usergroups_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringID of the usergroup to update
name: Option<String>The name of the group.
handle: Option<String>The handle used for mentioning the group in a channel, must be unique.
description: Option<String>The usergroup’s purpose or description.
is_visible: Option<bool>Configure whether or not this usergroup should be visible in the client.
Implementations