#[non_exhaustive]pub struct AdminUsergroupsUploadUsersRequest {
pub id: String,
pub file: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.usergroups.uploadUsers: Add members to an existing organizational usergroup in bulk via CSV upload.
Send it with SlackClient::admin_usergroups_upload_users.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringID of the usergroup to upload users to
file: Option<String>Csv of users to upload in format member id, email
Implementations