#[non_exhaustive]pub struct AdminUsersAssignRequest {
pub team_id: String,
pub user_id: String,
pub is_restricted: Option<bool>,
pub is_ultra_restricted: Option<bool>,
pub channel_ids: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.users.assign: Add an Enterprise user to a workspace.
Send it with SlackClient::admin_users_assign.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: StringThe ID (T1234) of the workspace.
user_id: StringThe ID of the user to add to the workspace.
is_restricted: Option<bool>True if user should be added to the workspace as a guest.
is_ultra_restricted: Option<bool>True if user should be added to the workspace as a single-channel guest.
channel_ids: Option<String>Comma separated values of channel IDs to add user in the new workspace.
Implementations