#[non_exhaustive]pub struct AdminUsersInviteRequest {
pub team_id: String,
pub email: String,
pub channel_ids: String,
pub custom_message: Option<String>,
pub real_name: Option<String>,
pub resend: Option<bool>,
pub is_restricted: Option<bool>,
pub is_ultra_restricted: Option<bool>,
pub guest_expiration_ts: Option<String>,
pub email_password_policy_enabled: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.users.invite: Invite a user to a workspace.
Send it with SlackClient::admin_users_invite.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: StringThe ID (T1234) of the workspace.
email: StringThe email address of the person to invite.
channel_ids: StringA comma-separated list of channel_ids for this user to join. At least one channel is required.
custom_message: Option<String>An optional message to send to the user in the invite email.
real_name: Option<String>Full name of the user.
resend: Option<bool>Allow this invite to be resent in the future if a user has not signed up yet. Resending can only be done via the UI and has no expiration. (default: false)
is_restricted: Option<bool>Is this user a multi-channel guest user? (default: false)
is_ultra_restricted: Option<bool>Is this user a single channel guest user? (default: false)
guest_expiration_ts: Option<String>Timestamp when guest account should be disabled. Only include this timestamp if you are inviting a guest user and you want their account to expire on a certain date.
email_password_policy_enabled: Option<bool>Allow invited user to sign in via email and password. Only available for Enterprise org teams via admin invite.