#[non_exhaustive]pub struct AdminUsersListRequest {
pub team_id: Option<String>,
pub cursor: Option<String>,
pub is_active: Option<bool>,
pub include_deactivated_user_workspaces: Option<bool>,
pub only_guests: Option<bool>,
pub include_admins: Option<bool>,
pub include_owners: Option<bool>,
pub limit: Option<i64>,
}Expand description
Arguments for the Slack Web API method admin.users.list: List users on a workspace
Send it with SlackClient::admin_users_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: Option<String>The ID (T1234) of a workspace. Filters results to just the specified workspace.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page.
is_active: Option<bool>If true, only active users will be returned. If false, only deactivated users will be returned. Default is true.
include_deactivated_user_workspaces: Option<bool>Only applies with org token and no team_id. If true, return workspaces for a user even if they may be deactivated on them. If false, return workspaces for a user only when user is active on them. Default is false.
only_guests: Option<bool>If true, returns only guests and their expiration dates that belong to the team_id.
include_admins: Option<bool>If true, only admin users will be returned (excludes owners). Returns all admins and owners when combined with include_owners. Cannot be used together with only_guests.
include_owners: Option<bool>If true, only owner users will be returned. Cannot be used together with only_guests.
limit: Option<i64>Limit for how many users to be retrieved per page