#[non_exhaustive]pub struct AdminUsersSessionGetSettingsRequest {
pub user_ids: Vec<String>,
}Expand description
Arguments for the Slack Web API method admin.users.session.getSettings: Get user-specific session settings—the session duration and what happens when the client closes—given a list of users.
Send it with SlackClient::admin_users_session_get_settings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_ids: Vec<String>The IDs of users you’d like to fetch session settings for. Note: if a user does not have any active sessions, they will not be returned in the response.
Implementations