#[non_exhaustive]pub struct AdminUsersSessionInvalidateRequest {
pub user_id: String,
pub session_id: i64,
}Expand description
Arguments for the Slack Web API method admin.users.session.invalidate: Revoke a single session for a user. The user will be forced to login to Slack.
Send it with SlackClient::admin_users_session_invalidate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: StringID of the user that the session belongs to.
session_id: i64ID of the session to invalidate.
Implementations