#[non_exhaustive]pub struct AdminUsersSessionResetBulkRequest {
pub user_ids: Vec<String>,
pub mobile_only: Option<bool>,
pub web_only: Option<bool>,
}Expand description
Arguments for the Slack Web API method admin.users.session.resetBulk: Enqueues an asynchronous job to wipe all valid sessions on all devices for a given list of users
Send it with SlackClient::admin_users_session_reset_bulk.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_ids: Vec<String>The list of up to 1,000 user IDs to wipe sessions for
mobile_only: Option<bool>Only expire mobile sessions (default: false)
web_only: Option<bool>Only expire web sessions (default: false)
Implementations