#[non_exhaustive]pub struct AdminUsersSetAdminRequest {
pub team_id: String,
pub user_id: String,
}Expand description
Arguments for the Slack Web API method admin.users.setAdmin: Set an existing regular user or owner to be a workspace or org admin.
Send it with SlackClient::admin_users_set_admin.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: StringThe ID of the workspace or organization.
user_id: StringThe ID of the user to designate as an admin.
Implementations