#[non_exhaustive]pub struct AdminUsersSetExpirationRequest {
pub user_id: String,
pub expiration_ts: i64,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method admin.users.setExpiration: Set an expiration for a guest user
Send it with SlackClient::admin_users_set_expiration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: StringThe ID of the user to set an expiration for.
expiration_ts: i64Epoch timestamp in seconds when guest account should be disabled.
team_id: Option<String>The ID (T1234) of the workspace.
Implementations