#[non_exhaustive]pub struct AdminWorkflowsPermissionsLookupRequest {
pub workflow_ids: Vec<String>,
pub max_workflow_triggers: Option<i64>,
}Expand description
Arguments for the Slack Web API method admin.workflows.permissions.lookup: Look up the permissions for a set of workflows
Send it with SlackClient::admin_workflows_permissions_lookup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workflow_ids: Vec<String>An array of workflow IDs to look up permissions for
max_workflow_triggers: Option<i64>Maximum number of triggers to fetch for each workflow when determining overall run permissions; max 1000
Implementations