#[non_exhaustive]pub struct AdminWorkflowsSearchRequest {Show 14 fields
pub query: Option<String>,
pub app_id: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i64>,
pub no_collaborators: Option<bool>,
pub collaborator_ids: Option<Vec<String>>,
pub num_trigger_ids: Option<i64>,
pub is_sales_elevate: Option<bool>,
pub source: Option<String>,
pub sort: Option<String>,
pub sort_dir: Option<String>,
pub trigger_type_id: Option<String>,
pub publish_status: Option<String>,
pub step_function_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method admin.workflows.search: Search workflows within the team or enterprise
Send it with SlackClient::admin_workflows_search.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query: Option<String>A search query to filter for workflow name or description
app_id: Option<String>The parent app ID for which to return workflows
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page
limit: Option<i64>The number of results that will be returned by the API on each invocation
no_collaborators: Option<bool>Only include workflows with no collaborators in the result; default is false
collaborator_ids: Option<Vec<String>>Only include workflows where all of the provided user IDs are a manager/collaborator of that workflow
num_trigger_ids: Option<i64>Number of trigger IDs to fetch for each workflow; default is 10
is_sales_elevate: Option<bool>Filter workflows by their Sales Elevate status
source: Option<String>Source of workflow creation, either from code or workflow builder
sort: Option<String>The field used to sort the returned workflows
sort_dir: Option<String>Sort direction. Possible values are asc for ascending order like (1, 2, 3) or (a, b, c), and desc for descending order like (3, 2, 1) or (c, b, a)
trigger_type_id: Option<String>Only include workflows with this trigger type
publish_status: Option<String>Filter workflows by their published status
step_function_ids: Option<Vec<String>>Only include workflows that use all of the provided step function ids