#[non_exhaustive]pub struct AgentsSessionsRenameRequest {
pub title: String,
pub channel_id: Option<String>,
pub thread_ts: Option<String>,
}Expand description
Arguments for the Slack Web API method agents.sessions.rename: Rename an agent session.
Send it with SlackClient::agents_sessions_rename.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: StringNew title for the agent session (1-200 characters). For a session channel, this also renames the channel.
channel_id: Option<String>ID of the channel containing the agent session. Required for public channels.
thread_ts: Option<String>Timestamp of the thread root message the session is scoped to. Required for thread-based sessions in regular channels and DMs. Must be omitted for session channels.
Implementations