AgentsSessionsSetStatusRequest

Struct AgentsSessionsSetStatusRequest 

#[non_exhaustive]
pub struct AgentsSessionsSetStatusRequest { pub status: String, pub channel_id: Option<String>, pub thread_ts: Option<String>, pub title: Option<String>, pub initiator_user_id: Option<String>, pub icon_emoji: Option<String>, pub icon_url: Option<String>, pub username: Option<String>, }
Arguments for the Slack Web API method agents.sessions.setStatus: Set an agent session’s lifecycle status, creating the session if needed.

Send it with SlackClient::agents_sessions_set_status.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
status: String

The lifecycle status to set.

channel_id: Option<String>

ID of the channel containing the agent session. Required for public channels.

thread_ts: Option<String>

Timestamp of the thread root message the session is scoped to. Required for thread-based sessions in regular channels and DMs. Must be omitted for session channels.

title: Option<String>

Title for the agent session (max 200 characters). Only used when creating a new session; ignored if the session already exists. To rename an existing session, use agents.sessions.rename.

initiator_user_id: Option<String>

The user who initiated the session. Only used when creating a new session; ignored if the session already exists. Must be a member of the channel.

icon_emoji: Option<String>

Emoji to use as the agent’s icon. Takes priority over icon_url. Remains in effect until you clear it (pass null) or set a new value. Requires the chat:write.customize scope.

icon_url: Option<String>

URL to an image to use as the agent’s icon. Remains in effect until you clear it (pass null) or set a new value. Requires the chat:write.customize scope.

username: Option<String>

Display name override for the agent (max 200 characters). Remains in effect until you clear it (pass null) or set a new value. Requires the chat:write.customize scope.

Implementations

Source

impl AgentsSessionsSetStatusRequest

pub fn new(status: impl Into<String>) -> Self

pub fn channel_id(self, channel_id: impl Into<String>) -> Self

pub fn thread_ts(self, thread_ts: impl Into<String>) -> Self

pub fn title(self, title: impl Into<String>) -> Self

pub fn initiator_user_id(self, initiator_user_id: impl Into<String>) -> Self

pub fn icon_emoji(self, icon_emoji: impl Into<String>) -> Self

pub fn icon_url(self, icon_url: impl Into<String>) -> Self

pub fn username(self, username: impl Into<String>) -> Self