#[non_exhaustive]pub struct AppsAuthExternalDeleteRequest {
pub app_id: Option<String>,
pub provider_key: Option<String>,
pub external_token_id: Option<String>,
}Expand description
Arguments for the Slack Web API method apps.auth.external.delete: Delete external auth tokens only on the Slack side
Send it with SlackClient::apps_auth_external_delete.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_id: Option<String>The id of the app whose tokens you want to delete
provider_key: Option<String>The provider key of the provider whose tokens you want to delete
external_token_id: Option<String>The id of the token that you want to delete
Implementations