#[non_exhaustive]pub struct AppsAuthExternalGetRequest {
pub external_token_id: String,
pub force_refresh: Option<bool>,
}Expand description
Arguments for the Slack Web API method apps.auth.external.get: Get the access token for the provided token ID
Send it with SlackClient::apps_auth_external_get.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.external_token_id: StringThe id of the token you want to get the token for
force_refresh: Option<bool>Always refresh existing token before returning even when the token has not expired
Implementations