#[non_exhaustive]pub struct AppsDatastoreQueryRequest {
pub datastore: String,
pub expression: Option<String>,
pub expression_attributes: Option<Value>,
pub expression_values: Option<Value>,
pub app_id: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i64>,
}Expand description
Arguments for the Slack Web API method apps.datastore.query: Query a datastore for items
Send it with SlackClient::apps_datastore_query.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.datastore: StringName of the datastore
expression: Option<String>A query filter expression
expression_attributes: Option<Value>A map of attributes referenced in expression
expression_values: Option<Value>A map of values referenced in expression
app_id: Option<String>Required if calling with user token
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page
limit: Option<i64>The maximum number of items to evaluate for a given request (not necessarily the number of matching items). If the given request dataset size exceeds 1 MB before reaching the limit, the returned item count will likely be less than the limit. In any case where there are more items available beyond an imposed limit, a next_cursor value will be provided for use in subsequent requests.