#[non_exhaustive]pub struct AppsEventAuthorizationsListRequest {
pub event_context: String,
pub cursor: Option<String>,
pub limit: Option<i64>,
}Expand description
Arguments for the Slack Web API method apps.event.authorizations.list: Get a list of authorizations for the given event context. Each authorization represents an app installation that the event is visible to.
Send it with SlackClient::apps_event_authorizations_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_context: Stringcursor: Option<String>limit: Option<i64>Implementations