#[non_exhaustive]pub struct AppsManifestCreateRequest {
pub manifest: String,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method apps.manifest.create: Create an app from an app manifest.
Send it with SlackClient::apps_manifest_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.manifest: StringA JSON app manifest encoded as a string. This manifest must use a valid app manifest schema - read our guide to creating one.
team_id: Option<String>When called with an org token, which specific team to create app on
Implementations