#[non_exhaustive]pub struct AppsManifestUpdateRequest {
pub manifest: String,
pub app_id: String,
}Expand description
Arguments for the Slack Web API method apps.manifest.update: Update an app from an app manifest
Send it with SlackClient::apps_manifest_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.manifest: StringA JSON app manifest encoded as a string. This manifest must use a valid app manifest schema - read our guide to creating one. As this method entirely replaces any previous configuration, manifest must contain both unmodified and modified fields.
app_id: StringThe ID of the app whose configuration you want to update.
Implementations