#[non_exhaustive]pub struct AppsManifestValidateRequest {
pub manifest: String,
pub app_id: Option<String>,
}Expand description
Arguments for the Slack Web API method apps.manifest.validate: Validate an app manifest
Send it with SlackClient::apps_manifest_validate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.manifest: StringThe manifest to be validated. Will be validated against the app manifest schema - read our guide.
app_id: Option<String>The ID of the app whose configuration you want to validate.
Implementations