#[non_exhaustive]pub struct AppsUserConnectionUpdateRequest {
pub user_id: String,
pub status: String,
}Expand description
Arguments for the Slack Web API method apps.user.connection.update: Updates the connection status between a user and an app.
Send it with SlackClient::apps_user_connection_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: StringThe ID of the user for the status update.
status: StringThe status that should be set for the user.
Implementations