AssistantSearchContextRequest

Struct AssistantSearchContextRequest 

#[non_exhaustive]
pub struct AssistantSearchContextRequest {
Show 20 fields pub query: String, pub action_token: Option<String>, pub channel_types: Option<Vec<String>>, pub content_types: Option<Vec<String>>, pub include_bots: Option<bool>, pub include_deleted_users: Option<bool>, pub before: Option<i64>, pub after: Option<i64>, pub include_context_messages: Option<bool>, pub context_channel_id: Option<String>, pub cursor: Option<String>, pub limit: Option<i64>, pub sort: Option<String>, pub sort_dir: Option<String>, pub include_message_blocks: Option<bool>, pub highlight: Option<bool>, pub term_clauses: Option<Vec<Value>>, pub modifiers: Option<String>, pub include_archived_channels: Option<bool>, pub disable_semantic_search: Option<bool>,
}
Arguments for the Slack Web API method assistant.search.context: Searches messages, files, channels and users across your Slack organization.

Send it with SlackClient::assistant_search_context.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
query: String

User prompt or search query

action_token: Option<String>

Send action_token as received in a message event.

channel_types: Option<Vec<String>>

Mix and match channel types by providing a comma-separated list of any combination of public_channel, private_channel, mpim, im.

content_types: Option<Vec<String>>

Content types to include, a comma-separated list of any combination of messages, files, channels, users.

include_bots: Option<bool>

Whether the results should include bots.

include_deleted_users: Option<bool>

Whether to include deleted users in the user search results. Defaults to false.

before: Option<i64>

UNIX timestamp filter. If present, filters for results before this date.

after: Option<i64>

UNIX timestamp filter. If present, filters for results after this date.

include_context_messages: Option<bool>

Whether to include context messages surrounding the main message result. Defaults to false if unspecified.

context_channel_id: Option<String>

Context channel ID to support scoping the search when applicable.

cursor: Option<String>

The cursor returned by the API. Leave this blank for the first request and use this to get the next page of results.

limit: Option<i64>

Number of results to return, up to a max of 20. Defaults to 20.

sort: Option<String>

The field to sort the results by. Defaults to score. Can be one of: score, timestamp.

sort_dir: Option<String>

The direction to sort the results by. Defaults to desc.

include_message_blocks: Option<bool>

Whether to return the message blocks in the response.

highlight: Option<bool>

Whether to highlight the search query in the results. Defaults to false if unspecified.

term_clauses: Option<Vec<Value>>

A list of term clauses. A term clause is a string with search terms. Search results returned will match every term clause specified (i.e., conjunctive normal form).

modifiers: Option<String>

A string containing only modifiers in the format of modifier:value. Search results returned will match the modifier value. For now modifiers only affect term clauses.

include_archived_channels: Option<bool>

Whether to include archived channels in the search results.

disable_semantic_search: Option<bool>

Whether to disable semantic search. When true, only keyword-based search is used. Defaults to false.

Implementations

Source

impl AssistantSearchContextRequest

pub fn new(query: impl Into<String>) -> Self

pub fn action_token(self, action_token: impl Into<String>) -> Self

pub fn channel_types(self, channel_types: Vec<String>) -> Self

pub fn content_types(self, content_types: Vec<String>) -> Self

pub fn include_bots(self, include_bots: bool) -> Self

pub fn include_deleted_users(self, include_deleted_users: bool) -> Self

pub fn before(self, before: i64) -> Self

pub fn after(self, after: i64) -> Self

pub fn include_context_messages(self, include_context_messages: bool) -> Self

pub fn context_channel_id(self, context_channel_id: impl Into<String>) -> Self

pub fn cursor(self, cursor: impl Into<String>) -> Self

pub fn limit(self, limit: i64) -> Self

pub fn sort(self, sort: impl Into<String>) -> Self

pub fn sort_dir(self, sort_dir: impl Into<String>) -> Self

pub fn include_message_blocks(self, include_message_blocks: bool) -> Self

pub fn highlight(self, highlight: bool) -> Self

pub fn term_clauses(self, term_clauses: Vec<Value>) -> Self

pub fn modifiers(self, modifiers: impl Into<String>) -> Self

pub fn include_archived_channels(self, include_archived_channels: bool) -> Self