#[non_exhaustive]pub struct AssistantThreadsSetStatusRequest {
pub channel_id: String,
pub thread_ts: String,
pub status: String,
pub loading_messages: Option<Vec<Value>>,
pub icon_emoji: Option<String>,
pub icon_url: Option<String>,
pub username: Option<String>,
}Expand description
Arguments for the Slack Web API method assistant.threads.setStatus: Set the status for an AI assistant thread.
Send it with SlackClient::assistant_threads_set_status.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringChannel ID containing the assistant thread.
thread_ts: StringMessage timestamp of the thread of where to set the status.
status: StringStatus of the specified bot user, e.g., ‘is thinking…’. A two minute timeout applies, which will cause the status to be removed if no message has been sent.
loading_messages: Option<Vec<Value>>The list of messages to rotate through as a loading indicator. Maximum of 10 messages.
icon_emoji: Option<String>Emoji to use as the icon for this message. Overrides icon_url.
icon_url: Option<String>Image URL to use as the icon for this message.
username: Option<String>The bot’s username to display.
Implementations
Sourceimpl AssistantThreadsSetStatusRequest
impl AssistantThreadsSetStatusRequest
pub fn new( channel_id: impl Into<String>, thread_ts: impl Into<String>, status: impl Into<String>, ) -> Self
pub fn loading_messages(self, loading_messages: Vec<Value>) -> Self
pub fn icon_emoji(self, icon_emoji: impl Into<String>) -> Self
pub fn icon_url(self, icon_url: impl Into<String>) -> Self
pub fn username(self, username: impl Into<String>) -> Self