#[non_exhaustive]pub struct AssistantThreadsSetSuggestedPromptsRequest {
pub channel_id: String,
pub prompts: String,
pub thread_ts: Option<String>,
pub title: Option<String>,
}Expand description
Arguments for the Slack Web API method assistant.threads.setSuggestedPrompts: Set suggested prompts for the given assistant thread
Send it with SlackClient::assistant_threads_set_suggested_prompts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringChannel ID containing the assistant thread.
prompts: StringEach prompt should be supplied with its title and message attribute.
thread_ts: Option<String>Message timestamp of the thread to set suggested prompts for. If not provided, the prompts will be set for the latest message in the channel.
title: Option<String>Title for the list of provided prompts. For example: Suggested Prompts, Related Questions.
Implementations