#[non_exhaustive]pub struct AuthTeamsListRequest {
pub limit: Option<i64>,
pub cursor: Option<String>,
pub include_icon: Option<bool>,
}Expand description
Arguments for the Slack Web API method auth.teams.list: Obtain a full list of workspaces your org-wide app has been approved for.
Send it with SlackClient::auth_teams_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.limit: Option<i64>The maximum number of workspaces to return. Must be a positive integer no larger than 1000.
cursor: Option<String>Set cursor to next_cursor returned by the previous call to list items in the next page.
include_icon: Option<bool>Whether to return icon paths for each workspace. An icon path represents a URI pointing to the image signifying the workspace.
Implementations