CallsAddRequest

Struct CallsAddRequest 

#[non_exhaustive]
pub struct CallsAddRequest { pub external_unique_id: String, pub join_url: String, pub external_display_id: Option<String>, pub desktop_app_join_url: Option<String>, pub date_start: Option<i64>, pub title: Option<String>, pub created_by: Option<String>, pub users: Option<Vec<Value>>, }
Arguments for the Slack Web API method calls.add: Registers a new Call.

Send it with SlackClient::calls_add.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
external_unique_id: String

An ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.

join_url: String

The URL required for a client to join the Call.

external_display_id: Option<String>

An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.

desktop_app_join_url: Option<String>

When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.

date_start: Option<i64>

Unix timestamp of the call start time

title: Option<String>

The name of the Call.

created_by: Option<String>

The valid Slack user ID of the user who created this Call. When this method is called with a user token, the created_by field is optional and defaults to the authed user of the token. Otherwise, the field is required.

users: Option<Vec<Value>>

The list of users to register as participants in the Call. Read more on how to specify users here.

Implementations

Source

impl CallsAddRequest

pub fn new( external_unique_id: impl Into<String>, join_url: impl Into<String>, ) -> Self

pub fn external_display_id(self, external_display_id: impl Into<String>) -> Self

pub fn desktop_app_join_url( self, desktop_app_join_url: impl Into<String>, ) -> Self

pub fn date_start(self, date_start: i64) -> Self

pub fn title(self, title: impl Into<String>) -> Self

pub fn created_by(self, created_by: impl Into<String>) -> Self

pub fn users(self, users: Vec<Value>) -> Self