#[non_exhaustive]pub struct CallsUpdateRequest {
pub id: String,
pub title: Option<String>,
pub join_url: Option<String>,
pub desktop_app_join_url: Option<String>,
}Expand description
Arguments for the Slack Web API method calls.update: Updates information about a Call.
Send it with SlackClient::calls_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Stringid returned by the calls.add method.
title: Option<String>The name of the Call.
join_url: Option<String>The URL required for a client to join the Call.
desktop_app_join_url: Option<String>When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
Implementations