#[non_exhaustive]pub struct CanvasesAccessSetRequest {
pub canvas_id: String,
pub access_level: String,
pub channel_ids: Option<Vec<String>>,
pub user_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method canvases.access.set: Sets the access level to a canvas for specified entities
Send it with SlackClient::canvases_access_set.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.canvas_id: StringEncoded ID of the canvas
access_level: StringDesired level of access
channel_ids: Option<Vec<String>>List of channels you wish to update access for. Can only be used if user_ids is not provided.
user_ids: Option<Vec<String>>List of users you wish to update access for. Can only be used if channel_ids is not provided.
Implementations