#[non_exhaustive]pub struct CanvasesCreateRequest {
pub title: Option<String>,
pub document_content: Option<String>,
pub channel_id: Option<String>,
}Expand description
Arguments for the Slack Web API method canvases.create: Create canvas for a user
Send it with SlackClient::canvases_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>Title of the newly created canvas
document_content: Option<String>Structure describing the type and value of the content to create. The markdown content is limited to 1 MiB (1,048,576 characters).
channel_id: Option<String>Channel ID of the channel the canvas will be tabbed in. This is a required field for free teams.
Implementations