#[non_exhaustive]pub struct ChatAppendStreamRequest {
pub channel: String,
pub ts: String,
pub chunks: Option<Vec<Value>>,
pub markdown_text: Option<String>,
}Expand description
Arguments for the Slack Web API method chat.appendStream: Append text to an existing streaming conversation
Send it with SlackClient::chat_append_stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringAn encoded ID that represents a channel, private group, or DM
ts: StringThe timestamp of the streaming message.
chunks: Option<Vec<Value>>Array of streaming chunks.
markdown_text: Option<String>Accepts message text formatted in markdown. Limit this field to 12,000 characters. This text is what will be appended to the message received so far.
Implementations