#[non_exhaustive]pub struct ChatDeleteRequest {
pub channel: String,
pub ts: String,
pub as_user: Option<bool>,
}Expand description
Arguments for the Slack Web API method chat.delete: Deletes a message.
Send it with SlackClient::chat_delete.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel containing the message to be deleted.
ts: StringTimestamp of the message to be deleted.
as_user: Option<bool>(Legacy) Pass true to delete the message as the authed user with chat:write:user scope. Bot users in this context are considered authed users. See legacy as_user parameter below.
Implementations