#[non_exhaustive]pub struct ChatDeleteScheduledMessageRequest {
pub channel: String,
pub scheduled_message_id: String,
pub as_user: Option<bool>,
}Expand description
Arguments for the Slack Web API method chat.deleteScheduledMessage: Deletes a pending scheduled message from the queue.
Send it with SlackClient::chat_delete_scheduled_message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringThe channel the scheduled_message is posting to
scheduled_message_id: Stringscheduled_message_id returned from call to chat.scheduleMessage
as_user: Option<bool>Pass true to delete the message as the authed user with chat:write:user scope. Bot users in this context are considered authed users. If unused or false, the message will be deleted with chat:write:bot scope.
Implementations