#[non_exhaustive]pub struct ChatGetPermalinkRequest {
pub channel: String,
pub message_ts: String,
}Expand description
Arguments for the Slack Web API method chat.getPermalink: Retrieve a permalink URL for a specific extant message
Send it with SlackClient::chat_get_permalink.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringThe ID of the conversation or channel containing the message
message_ts: StringA message’s ts value, uniquely identifying it within a channel
Implementations