#[non_exhaustive]pub struct ChatScheduledMessagesListRequest {
pub channel: Option<String>,
pub cursor: Option<String>,
pub latest: Option<String>,
pub limit: Option<i64>,
pub oldest: Option<String>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method chat.scheduledMessages.list: Returns a list of scheduled messages.
Send it with SlackClient::chat_scheduled_messages_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: Option<String>The channel of the scheduled messages
cursor: Option<String>For pagination purposes, this is the cursor value returned from a previous call to chat.scheduledmessages.list indicating where you want to start this call from.
latest: Option<String>A Unix timestamp of the latest value in the time range
limit: Option<i64>Maximum number of original entries to return.
oldest: Option<String>A Unix timestamp of the oldest value in the time range
team_id: Option<String>encoded team id to list channels in, required if org token is used
Implementations
Sourceimpl ChatScheduledMessagesListRequest
impl ChatScheduledMessagesListRequest
pub fn new() -> Self
pub fn channel(self, channel: impl Into<String>) -> Self
pub fn cursor(self, cursor: impl Into<String>) -> Self
pub fn latest(self, latest: impl Into<String>) -> Self
pub fn limit(self, limit: i64) -> Self
pub fn oldest(self, oldest: impl Into<String>) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self