#[non_exhaustive]pub struct ChatStartStreamRequest {
pub channel: String,
pub chunks: Option<Vec<Value>>,
pub markdown_text: Option<String>,
pub thread_ts: Option<String>,
pub recipient_user_id: Option<String>,
pub recipient_team_id: Option<String>,
pub task_display_mode: Option<String>,
pub icon_emoji: Option<String>,
pub icon_url: Option<String>,
pub username: Option<String>,
}Expand description
Arguments for the Slack Web API method chat.startStream: Start a new streaming conversation
Send it with SlackClient::chat_start_stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringAn encoded ID that represents a channel, thread, or DM.
chunks: Option<Vec<Value>>Array of streaming chunks. Can include markdown text chunk objects, task update chunk objects, plan update chunks, or blocks chunks.
markdown_text: Option<String>Accepts message text formatted in markdown. Limit this field to 12,000 characters.
thread_ts: Option<String>Provide another message’s ts value to reply to. Omit it to stream a top-level message instead of a thread reply; this is only supported in channels where the whole channel is one session, such as Slack Code, and returns invalid_thread_ts elsewhere. Passing "0" is equivalent to omitting it.
recipient_user_id: Option<String>The encoded ID of the user to receive the streaming text. Required when streaming to channels.
recipient_team_id: Option<String>The encoded ID of the team the user receiving the streaming text belongs to. Required when streaming to channels.
task_display_mode: Option<String>Specifies how tasks are displayed in the message. timeline task updates render as individual task cards interleaved with streamed text. plan task updates render together in a plan block.
icon_emoji: Option<String>Emoji to use as the icon for this message. Overrides icon_url.
icon_url: Option<String>Image URL to use as the icon for this message.
username: Option<String>The bot’s username to display.