#[non_exhaustive]pub struct ChatStopStreamRequest {
pub channel: String,
pub ts: String,
pub chunks: Option<Vec<Value>>,
pub markdown_text: Option<String>,
pub blocks: Option<Vec<Block>>,
pub metadata: Option<MessageMetadata>,
pub session_status: Option<String>,
}Expand description
Arguments for the Slack Web API method chat.stopStream: Stop a streaming conversation
Send it with SlackClient::chat_stop_stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringAn encoded ID that represents a channel, private group, or DM
ts: StringThe timestamp of the streaming message.
chunks: Option<Vec<Value>>Array of streaming chunks. Can include markdown text chunk objects, task update chunk objects, plan update chunks, or blocks chunks.
markdown_text: Option<String>Accepts message text formatted in markdown. Limit this field to 12,000 characters.
blocks: Option<Vec<Block>>A list of blocks that will be rendered at the bottom of the finalized message.
metadata: Option<MessageMetadata>JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace.
session_status: Option<String>The session status to set after stopping the stream.