ChatUnfurlRequest

Struct ChatUnfurlRequest 

#[non_exhaustive]
pub struct ChatUnfurlRequest { pub channel: Option<String>, pub ts: Option<String>, pub unfurls: Option<String>, pub user_auth_message: Option<String>, pub user_auth_required: Option<bool>, pub user_auth_url: Option<String>, pub user_auth_blocks: Option<Vec<Block>>, pub unfurl_id: Option<String>, pub source: Option<String>, }
Arguments for the Slack Web API method chat.unfurl: Provide custom unfurl behavior for user-posted URLs

Send it with SlackClient::chat_unfurl.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
channel: Option<String>

Channel ID of the message. Both channel and ts must be provided together, or unfurl_id and source must be provided together. Required for public channels.

ts: Option<String>

Timestamp of the message to add unfurl behavior to. Required for public channels.

unfurls: Option<String>

URL-encoded JSON map with keys set to URLs featured in the message, pointing to their unfurl blocks or message attachments. Required for public channels.

user_auth_message: Option<String>

Provide a simply-formatted string to send as an ephemeral message to the user as invitation to authenticate further and enable full unfurling behavior. Provides two buttons, Not now or Never ask me again.

user_auth_required: Option<bool>

Set to true or 1 to indicate the user must install your Slack app to trigger unfurls for this domain

user_auth_url: Option<String>

Send users to this custom URL where they will complete authentication in your app to fully trigger unfurling. Value should be properly URL-encoded.

user_auth_blocks: Option<Vec<Block>>

Provide a JSON based array of structured blocks presented as URL-encoded string to send as an ephemeral message to the user as invitation to authenticate further and enable full unfurling behavior

unfurl_id: Option<String>

The ID of the link to unfurl. Both unfurl_id and source must be provided together, or channel and ts must be provided together.

source: Option<String>

The source of the link to unfurl. The source may either be composer, when the link is inside the message composer, or conversations_history, when the link has been posted to a conversation.

Implementations

Source

impl ChatUnfurlRequest

pub fn new() -> Self

pub fn channel(self, channel: impl Into<String>) -> Self

pub fn ts(self, ts: impl Into<String>) -> Self

pub fn unfurls(self, unfurls: impl Into<String>) -> Self

pub fn user_auth_message(self, user_auth_message: impl Into<String>) -> Self

pub fn user_auth_required(self, user_auth_required: bool) -> Self

pub fn user_auth_url(self, user_auth_url: impl Into<String>) -> Self

pub fn user_auth_blocks(self, user_auth_blocks: Vec<Block>) -> Self

pub fn unfurl_id(self, unfurl_id: impl Into<String>) -> Self

pub fn source(self, source: impl Into<String>) -> Self