ChatUpdateRequest

Struct ChatUpdateRequest 

#[non_exhaustive]
pub struct ChatUpdateRequest {
Show 13 fields pub channel: String, pub ts: String, pub as_user: Option<bool>, pub attachments: Option<Vec<Attachment>>, pub unfurled_attachments: Option<String>, pub blocks: Option<Vec<Block>>, pub markdown_text: Option<String>, pub metadata: Option<MessageMetadata>, pub link_names: Option<bool>, pub parse: Option<String>, pub text: Option<String>, pub reply_broadcast: Option<bool>, pub file_ids: Option<Vec<String>>,
}
Arguments for the Slack Web API method chat.update: Updates a message.

Send it with SlackClient::chat_update.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
channel: String

Channel containing the message to be updated. For direct messages, ensure that this value is a DM ID (starts with D) instead of a User ID (starts with either U or W).

ts: String

Timestamp of the message to be updated.

as_user: Option<bool>

Pass true to update the message as the authed user. Bot users in this context are considered authed users.

attachments: Option<Vec<Attachment>>

A JSON-based array of structured attachments, presented as a URL-encoded string.

unfurled_attachments: Option<String>

A JSON-based array of structured attachments, presented as a URL-encoded string.

blocks: Option<Vec<Block>>

A JSON-based array of structured blocks, presented as a URL-encoded string.

markdown_text: Option<String>

Accepts message text formatted in markdown. This argument should not be used in conjunction with blocks or text. Limit this field to 12,000 characters.

metadata: Option<MessageMetadata>

JSON object with event_type and event_payload fields, presented as a URL-encoded string. If you don’t include this field, the message’s previous metadata will be retained. To remove previous metadata, include an empty object for this field. Metadata you post to Slack is accessible to any app or user who is a member of that workspace.

link_names: Option<bool>

Find and link channel names and usernames. Defaults to none. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, none.

parse: Option<String>

Change how messages are treated. Defaults to client, unlike chat.postMessage. Accepts either none or full. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, client.

text: Option<String>

How this field works and whether it is required depends on other fields you use in your API call. See below for more detail.

reply_broadcast: Option<bool>

Broadcast an existing thread reply to make it visible to everyone in the channel or conversation.

file_ids: Option<Vec<String>>

Array of new file ids that will be sent with this message.

Implementations

Source

impl ChatUpdateRequest

pub fn new(channel: impl Into<String>, ts: impl Into<String>) -> Self

pub fn as_user(self, as_user: bool) -> Self

pub fn attachments(self, attachments: Vec<Attachment>) -> Self

pub fn unfurled_attachments( self, unfurled_attachments: impl Into<String>, ) -> Self

pub fn blocks(self, blocks: Vec<Block>) -> Self

pub fn markdown_text(self, markdown_text: impl Into<String>) -> Self

pub fn metadata(self, metadata: MessageMetadata) -> Self

pub fn parse(self, parse: impl Into<String>) -> Self

pub fn text(self, text: impl Into<String>) -> Self

pub fn reply_broadcast(self, reply_broadcast: bool) -> Self

pub fn file_ids(self, file_ids: Vec<String>) -> Self