#[non_exhaustive]pub struct ConversationsCanvasesCreateRequest {
pub channel_id: String,
pub document_content: Option<String>,
pub title: Option<String>,
}Expand description
Arguments for the Slack Web API method conversations.canvases.create: Create a channel canvas for a channel
Send it with SlackClient::conversations_canvases_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: StringChannel ID of the channel the canvas will be tabbed in.
document_content: Option<String>Structure describing the type and value of the content to create. The markdown content is limited to 1 MiB (1,048,576 characters).
title: Option<String>Title of the newly created canvas
Implementations