#[non_exhaustive]pub struct ConversationsCreateRequest {
pub name: String,
pub is_private: Option<bool>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method conversations.create: Initiates a public or private channel-based conversation
Send it with SlackClient::conversations_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the public or private channel to create
is_private: Option<bool>Create a private channel instead of a public one
team_id: Option<String>encoded team id to create the channel in, required if org token is used
Implementations