#[non_exhaustive]pub struct ConversationsDeclineSharedInviteRequest {
pub invite_id: String,
pub target_team: Option<String>,
}Expand description
Arguments for the Slack Web API method conversations.declineSharedInvite: Declines a Slack Connect channel invite.
Send it with SlackClient::conversations_decline_shared_invite.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.invite_id: StringID of the Slack Connect invite to decline. Subscribe to the shared_channel_invite_accepted event to receive IDs of Slack Connect channel invites that have been accepted and are awaiting approval.
target_team: Option<String>The team or enterprise id of the other party involved in the invitation you are declining
Implementations