ConversationsHistoryRequest

Struct ConversationsHistoryRequest 

#[non_exhaustive]
pub struct ConversationsHistoryRequest { pub channel: String, pub cursor: Option<String>, pub include_all_metadata: Option<bool>, pub inclusive: Option<bool>, pub latest: Option<String>, pub limit: Option<i64>, pub oldest: Option<String>, }
Arguments for the Slack Web API method conversations.history: Fetches a conversation’s history of messages and events.

Send it with SlackClient::conversations_history.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
channel: String

Conversation ID to fetch history for.

cursor: Option<String>

Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.

include_all_metadata: Option<bool>

Return all metadata associated with this message.

inclusive: Option<bool>

Include messages with oldest or latest timestamps in results. Ignored unless either timestamp is specified.

latest: Option<String>

Only messages before this Unix timestamp will be included in results. Default is the current time.

limit: Option<i64>

The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the conversation history hasn’t been reached. Maximum of 999.

oldest: Option<String>

Only messages after this Unix timestamp will be included in results.

Implementations

Source

impl ConversationsHistoryRequest

pub fn new(channel: impl Into<String>) -> Self

pub fn cursor(self, cursor: impl Into<String>) -> Self

pub fn include_all_metadata(self, include_all_metadata: bool) -> Self

pub fn inclusive(self, inclusive: bool) -> Self

pub fn latest(self, latest: impl Into<String>) -> Self

pub fn limit(self, limit: i64) -> Self

pub fn oldest(self, oldest: impl Into<String>) -> Self