#[non_exhaustive]pub struct ConversationsInfoRequest {
pub channel: String,
pub include_locale: Option<bool>,
pub include_num_members: Option<bool>,
}Expand description
Arguments for the Slack Web API method conversations.info: Retrieve information about a conversation.
Send it with SlackClient::conversations_info.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringConversation ID to learn more about
include_locale: Option<bool>Set this to true to receive the locale for this conversation. Defaults to false
include_num_members: Option<bool>Set to true to include the member count for the specified conversation. Defaults to false
Implementations
Sourceimpl ConversationsInfoRequest
impl ConversationsInfoRequest
pub fn new(channel: impl Into<String>) -> Self
pub fn include_locale(self, include_locale: bool) -> Self
pub fn include_num_members(self, include_num_members: bool) -> Self