#[non_exhaustive]pub struct ConversationsInviteRequest {
pub channel: String,
pub users: String,
pub force: Option<bool>,
}Expand description
Arguments for the Slack Web API method conversations.invite: Invites users to a channel.
Send it with SlackClient::conversations_invite.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringThe ID of the public or private channel to invite user(s) to.
users: StringA comma separated list of user IDs. Up to 1000 users may be listed.
force: Option<bool>When set to true and multiple user IDs are provided, continue inviting the valid ones while disregarding invalid IDs. Defaults to false.
Implementations