#[non_exhaustive]pub struct ConversationsListConnectInvitesRequest {
pub team_id: Option<String>,
pub count: Option<i64>,
pub cursor: Option<String>,
}Expand description
Arguments for the Slack Web API method conversations.listConnectInvites: Lists shared channel invites that have been generated or received but have not been approved by all parties
Send it with SlackClient::conversations_list_connect_invites.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: Option<String>Encoded team id for the workspace to retrieve invites for, required if org token is used
count: Option<i64>Maximum number of invites to return
cursor: Option<String>Set to next_cursor returned by previous call to list items in subsequent page
Implementations