ConversationsListRequest

Struct ConversationsListRequest 

#[non_exhaustive]
pub struct ConversationsListRequest { pub cursor: Option<String>, pub exclude_archived: Option<bool>, pub limit: Option<i64>, pub team_id: Option<String>, pub types: Option<String>, }
Arguments for the Slack Web API method conversations.list: Lists all channels in a Slack team.

Send it with SlackClient::conversations_list.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cursor: Option<String>

Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.

exclude_archived: Option<bool>

Set to true to exclude archived channels from the list.

limit: Option<i64>

The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn’t been reached. Must be an integer under 1000.

team_id: Option<String>

encoded team id to list channels in, required if token belongs to org-wide app

types: Option<String>

Mix and match channel types by providing a comma-separated list of any combination of public_channel, private_channel, mpim, im

Implementations

Source

impl ConversationsListRequest

pub fn new() -> Self

pub fn cursor(self, cursor: impl Into<String>) -> Self

pub fn exclude_archived(self, exclude_archived: bool) -> Self

pub fn limit(self, limit: i64) -> Self

pub fn team_id(self, team_id: impl Into<String>) -> Self

pub fn types(self, types: impl Into<String>) -> Self