#[non_exhaustive]pub struct ConversationsMarkRequest {
pub channel: String,
pub ts: String,
}Expand description
Arguments for the Slack Web API method conversations.mark: Sets the read cursor in a channel.
Send it with SlackClient::conversations_mark.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel or conversation to set the read cursor for.
ts: StringUnique identifier of message you want marked as most recently seen in this conversation.
Implementations