#[non_exhaustive]pub struct ConversationsMembersRequest {
pub channel: String,
pub cursor: Option<String>,
pub limit: Option<i64>,
}Expand description
Arguments for the Slack Web API method conversations.members: Retrieve members of a conversation.
Send it with SlackClient::conversations_members.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringID of the conversation to retrieve members for
cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.
limit: Option<i64>The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn’t been reached.
Implementations