#[non_exhaustive]pub struct ConversationsOpenRequest {
pub channel: Option<String>,
pub return_im: Option<bool>,
pub users: Option<String>,
pub prevent_creation: Option<bool>,
}Expand description
Arguments for the Slack Web API method conversations.open: Opens or resumes a direct message or multi-person direct message.
Send it with SlackClient::conversations_open.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: Option<String>Resume a conversation by supplying an im or mpim’s ID. Or provide the users field instead.
return_im: Option<bool>Boolean, indicates you want the full IM channel definition in the response.
users: Option<String>Comma separated lists of users. If only one user is included, this creates a 1:1 DM. The ordering of the users is preserved whenever a multi-person direct message is returned. Supply a channel when not supplying users.
prevent_creation: Option<bool>Do not create a direct message or multi-person direct message. This is used to see if there is an existing dm or mpdm.
Implementations