#[non_exhaustive]pub struct ConversationsRepliesRequest {
pub channel: String,
pub ts: String,
pub cursor: Option<String>,
pub include_all_metadata: Option<bool>,
pub inclusive: Option<bool>,
pub latest: Option<String>,
pub limit: Option<i64>,
pub oldest: Option<String>,
}Expand description
Arguments for the Slack Web API method conversations.replies: Retrieve a thread of messages posted to a conversation
Send it with SlackClient::conversations_replies.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringConversation ID to fetch thread from.
ts: StringUnique identifier of either a thread’s parent message or a message in the thread. ts must be the timestamp of an existing message with 0 or more replies. If there are no replies then just the single message referenced by ts will return - it is just an ordinary, unthreaded message.
cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.
include_all_metadata: Option<bool>Return all metadata associated with this message.
inclusive: Option<bool>Include messages with oldest or latest timestamps in results. Ignored unless either timestamp is specified.
latest: Option<String>Only messages before this Unix timestamp will be included in results.
limit: Option<i64>The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn’t been reached.
oldest: Option<String>Only messages after this Unix timestamp will be included in results.