#[non_exhaustive]pub struct ConversationsRequestSharedInviteApproveRequest {
pub invite_id: String,
pub is_external_limited: Option<bool>,
pub channel_id: Option<String>,
pub message: Option<Value>,
}Expand description
Arguments for the Slack Web API method conversations.requestSharedInvite.approve: Approves a request to add an external user to a channel and sends them a Slack Connect invite
Send it with SlackClient::conversations_request_shared_invite_approve.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.invite_id: StringID of the requested shared channel invite to approve.
is_external_limited: Option<bool>Optional boolean on whether the invited team will have post-only permissions in the channel. Will override the value on the requested invite.
channel_id: Option<String>Optional channel_id to which external user will be invited to. Will override the value on the requested invite.
message: Option<Value>Object describing the text to send along with the invite. If this object is specified, both text and is_override are required properties. If is_override is set to true, text will override the original invitation message. Otherwise, text will be appended to the original invitation message. The total length of the message cannot exceed 560 characters. If is_override is set to false, the length of text and the user specified message on the invite request in total must be less than 560 characters.