#[non_exhaustive]pub struct ConversationsRequestSharedInviteDenyRequest {
pub invite_id: String,
pub message: Option<String>,
}Expand description
Arguments for the Slack Web API method conversations.requestSharedInvite.deny: Denies a request to invite an external user to a channel
Send it with SlackClient::conversations_request_shared_invite_deny.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.invite_id: StringID of the requested shared channel invite to deny.
message: Option<String>Optional message explaining why the request to invite was denied.
Implementations