#[non_exhaustive]pub struct ConversationsRequestSharedInviteListRequest {
pub user_id: Option<String>,
pub include_expired: Option<bool>,
pub include_approved: Option<bool>,
pub include_denied: Option<bool>,
pub invite_ids: Option<Vec<String>>,
pub limit: Option<i64>,
pub cursor: Option<String>,
}Expand description
Arguments for the Slack Web API method conversations.requestSharedInvite.list: Lists requests to add external users to channels with ability to filter.
Send it with SlackClient::conversations_request_shared_invite_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: Option<String>Optional filter to return invitation requests for the inviting user.
include_expired: Option<bool>When true expired invitation requests will be returned, otherwise they will be excluded
include_approved: Option<bool>When true approved invitation requests will be returned, otherwise they will be excluded
include_denied: Option<bool>When true denied invitation requests will be returned, otherwise they will be excluded
invite_ids: Option<Vec<String>>An optional list of invitation ids to look up
limit: Option<i64>The number of items to return. Must be between 1 - 1000 (inclusive).
cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. See pagination for more detail.