#[non_exhaustive]pub struct DndInfoRequest {
pub user: Option<String>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method dnd.info: Retrieves a user’s current Do Not Disturb status.
Send it with SlackClient::dnd_info.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user: Option<String>User to fetch status for (defaults to current user)
team_id: Option<String>Encoded team id where passed in user param belongs, required if org token is used. If no user param is passed, then a team which has access to the app should be passed
Implementations