#[non_exhaustive]pub struct DndTeamInfoRequest {
pub users: String,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method dnd.teamInfo: Retrieves the Do Not Disturb status for up to 50 users on a team.
Send it with SlackClient::dnd_team_info.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.users: StringComma-separated list of users to fetch Do Not Disturb status for
team_id: Option<String>Encoded team id where passed in users belong, required if org token is used
Implementations