#[non_exhaustive]pub struct EntityAcknowledgeCommentActionRequest {
pub trigger_id: String,
pub comment: Option<Value>,
pub error: Option<String>,
}Expand description
Arguments for the Slack Web API method entity.acknowledgeCommentAction: Acknowledge a comment post, edit, or delete on a Work Object. Apps call this method to confirm they have processed a comment action.
Send it with SlackClient::entity_acknowledge_comment_action.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trigger_id: StringA reference to the original user action that initiated the comment mutation
comment: Option<Value>The full comment data. Required for edit and post actions. See the comment schema for the full list of properties.
error: Option<String>Error message if the action failed in the app. When present, signals that the mutation could not be completed.
Implementations