#[non_exhaustive]pub struct EntityPresentCommentsRequest {
pub comments: Vec<Value>,
pub trigger_id: String,
pub cursor: Option<String>,
pub can_post_comment: Option<bool>,
pub delete_action_id: Option<String>,
pub user_auth_required: Option<bool>,
pub user_auth_url: Option<String>,
pub error: Option<String>,
}Expand description
Arguments for the Slack Web API method entity.presentComments: Provide comments for Work Objects. Apps call this method to send per-user flexpane comment data to the client.
Send it with SlackClient::entity_present_comments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.comments: Vec<Value>Array of comments to present to the user. See the comment schema for the full list of properties.
trigger_id: StringA reference to the original user action that initiated the request
cursor: Option<String>App supplied cursor used for pagination, will be sent in the next request for comments
can_post_comment: Option<bool>Indicates whether the user has permissions to post comments
delete_action_id: Option<String>The block action id that will be sent when a delete request is initiated for a comment.
user_auth_required: Option<bool>Set to true (or 1) to indicate that the user must authenticate to see the comments data.
user_auth_url: Option<String>A custom URL to which users are directed for authentication if required.
error: Option<String>