#[non_exhaustive]pub struct EntityPresentDetailsRequest {
pub trigger_id: String,
pub metadata: Option<Value>,
pub user_auth_required: Option<bool>,
pub user_auth_url: Option<String>,
pub error: Option<String>,
}Expand description
Arguments for the Slack Web API method entity.presentDetails: Provide custom flexpane behavior for Work Objects. Apps call this method to send per-user flexpane metadata to the client.
Send it with SlackClient::entity_present_details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trigger_id: StringA reference to the original user action that initiated the request.
metadata: Option<Value>URL-encoded JSON object containing flexpane metadata from the app that will be conformed to a Work Object metadata schema, keyed by entity ID.
user_auth_required: Option<bool>Set to true (or 1) to indicate that the user must authenticate to view full flexpane data.
user_auth_url: Option<String>A custom URL to which users are directed for authentication if required.
error: Option<String>Implementations
Sourceimpl EntityPresentDetailsRequest
impl EntityPresentDetailsRequest
pub fn new(trigger_id: impl Into<String>) -> Self
pub fn metadata(self, metadata: Value) -> Self
pub fn user_auth_required(self, user_auth_required: bool) -> Self
pub fn user_auth_url(self, user_auth_url: impl Into<String>) -> Self
pub fn error(self, error: impl Into<String>) -> Self