FilesCompleteUploadExternalRequest

Struct FilesCompleteUploadExternalRequest 

#[non_exhaustive]
pub struct FilesCompleteUploadExternalRequest { pub files: Vec<Value>, pub channel_id: Option<String>, pub thread_ts: Option<String>, pub channels: Option<String>, pub initial_comment: Option<String>, pub blocks: Option<Vec<Block>>, pub username: Option<String>, pub icon_url: Option<String>, pub icon_emoji: Option<String>, }
Arguments for the Slack Web API method files.completeUploadExternal: Finishes an upload started with files.getUploadURLExternal

Send it with SlackClient::files_complete_upload_external.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
files: Vec<Value>

Array of file ids and their corresponding (optional) titles.

channel_id: Option<String>

Channel ID where the file will be shared. If not specified the file will be private.

thread_ts: Option<String>

Provide another message’s ts value to upload this file as a reply. Never use a reply’s ts value; use its parent instead. Also make sure to provide only one channel when using ‘thread_ts’

channels: Option<String>

Comma-separated string of channel IDs or user IDs where the file will be shared.

initial_comment: Option<String>

The message text introducing the file in specified channels.

blocks: Option<Vec<Block>>

A JSON-based array of structured rich text blocks, presented as a URL-encoded string. If the initial_comment field is provided, the blocks field is ignored

username: Option<String>

Set your bot’s user name for the file share message. Requires the chat:write.customize scope.

icon_url: Option<String>

URL to an image to use as the icon for the file share message. Requires the chat:write.customize scope.

icon_emoji: Option<String>

Emoji to use as the icon for the file share message. Overrides icon_url. Requires the chat:write.customize scope.

Implementations

Source

impl FilesCompleteUploadExternalRequest

pub fn new(files: Vec<Value>) -> Self

pub fn channel_id(self, channel_id: impl Into<String>) -> Self

pub fn thread_ts(self, thread_ts: impl Into<String>) -> Self

pub fn channels(self, channels: impl Into<String>) -> Self

pub fn initial_comment(self, initial_comment: impl Into<String>) -> Self

pub fn blocks(self, blocks: Vec<Block>) -> Self

pub fn username(self, username: impl Into<String>) -> Self

pub fn icon_url(self, icon_url: impl Into<String>) -> Self

pub fn icon_emoji(self, icon_emoji: impl Into<String>) -> Self