#[non_exhaustive]pub struct FilesListRequest {
pub channel: Option<String>,
pub count: Option<i64>,
pub page: Option<i64>,
pub show_files_hidden_by_limit: Option<bool>,
pub team_id: Option<String>,
pub ts_from: Option<String>,
pub ts_to: Option<String>,
pub types: Option<String>,
pub user: Option<String>,
}Expand description
Arguments for the Slack Web API method files.list: List for a team, in a channel, or from a user with applied filters.
Send it with SlackClient::files_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: Option<String>Filter files appearing in a specific channel, indicated by its ID.
count: Option<i64>page: Option<i64>Show truncated file info for files hidden due to being too old, and the team who owns the file being over the file limit.
team_id: Option<String>encoded team id to list files in, required if org token is used
ts_from: Option<String>Filter files created after this timestamp (inclusive).
ts_to: Option<String>Filter files created before this timestamp (inclusive).
types: Option<String>Filter files by type (see below). You can pass multiple values in the types argument, like types=spaces,snippets.The default value is all, which does not filter the list.
user: Option<String>Filter files created by a single user.
Implementations
Sourceimpl FilesListRequest
impl FilesListRequest
pub fn new() -> Self
pub fn channel(self, channel: impl Into<String>) -> Self
pub fn count(self, count: i64) -> Self
pub fn page(self, page: i64) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self
pub fn ts_from(self, ts_from: impl Into<String>) -> Self
pub fn ts_to(self, ts_to: impl Into<String>) -> Self
pub fn types(self, types: impl Into<String>) -> Self
pub fn user(self, user: impl Into<String>) -> Self