#[non_exhaustive]pub struct FilesRemoteListRequest {
pub channel: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i64>,
pub ts_from: Option<String>,
pub ts_to: Option<String>,
}Expand description
Arguments for the Slack Web API method files.remote.list: Retrieve information about a remote file added to Slack
Send it with SlackClient::files_remote_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: Option<String>Filter files appearing in a specific channel, indicated by its ID.
cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.
limit: Option<i64>The maximum number of items to return.
ts_from: Option<String>Filter files created after this timestamp (inclusive).
ts_to: Option<String>Filter files created before this timestamp (inclusive).
Implementations
Sourceimpl FilesRemoteListRequest
impl FilesRemoteListRequest
pub fn new() -> Self
pub fn channel(self, channel: impl Into<String>) -> Self
pub fn cursor(self, cursor: impl Into<String>) -> Self
pub fn limit(self, limit: i64) -> Self
pub fn ts_from(self, ts_from: impl Into<String>) -> Self
pub fn ts_to(self, ts_to: impl Into<String>) -> Self