#[non_exhaustive]pub struct FilesRemoteShareRequest {
pub channels: String,
pub external_id: Option<String>,
pub file: Option<String>,
}Expand description
Arguments for the Slack Web API method files.remote.share: Share a remote file into a channel.
Send it with SlackClient::files_remote_share.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channels: StringComma-separated list of channel IDs where the file will be shared.
external_id: Option<String>The globally unique identifier (GUID) for the file, as set by the app registering the file with Slack. Either this field or file or both are required.
file: Option<String>Specify a file registered with Slack by providing its ID. Either this field or external_id or both are required.
Implementations