#[non_exhaustive]pub struct FunctionsCompleteSuccessRequest {
pub function_execution_id: String,
pub outputs: Value,
}Expand description
Arguments for the Slack Web API method functions.completeSuccess: Signal the successful completion of a function
Send it with SlackClient::functions_complete_success.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.function_execution_id: StringContext identifier that maps to the executed function
outputs: ValueA JSON-based object that conforms to the output parameters schema for the custom function defined in the manifest
Implementations