#[non_exhaustive]pub struct FunctionsDistributionsPermissionsListRequest {
pub function_id: Option<String>,
pub function_callback_id: Option<String>,
pub function_app_id: Option<String>,
}Expand description
Arguments for the Slack Web API method functions.distributions.permissions.list: List the access type of a custom slack function and include the users, team or org ids with access if its permission_type is set to named_entities
Send it with SlackClient::functions_distributions_permissions_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.function_id: Option<String>The encoded ID of the function
function_callback_id: Option<String>The callback ID defined in the function’s definition file
function_app_id: Option<String>The encoded ID of the app
Implementations
Sourceimpl FunctionsDistributionsPermissionsListRequest
impl FunctionsDistributionsPermissionsListRequest
pub fn new() -> Self
pub fn function_id(self, function_id: impl Into<String>) -> Self
pub fn function_callback_id( self, function_callback_id: impl Into<String>, ) -> Self
pub fn function_app_id(self, function_app_id: impl Into<String>) -> Self