#[non_exhaustive]pub struct FunctionsDistributionsPermissionsSetRequest {
pub function_id: Option<String>,
pub function_callback_id: Option<String>,
pub function_app_id: Option<String>,
pub permission_type: Option<String>,
pub user_ids: Option<Vec<String>>,
pub team_ids: Option<Vec<String>>,
pub org_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method functions.distributions.permissions.set: Set the access type of a custom slack function and define the users, team or org ids to be granted access if permission_type is set to named_entities
Send it with SlackClient::functions_distributions_permissions_set.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.function_id: Option<String>The encoded ID of the function
function_callback_id: Option<String>The callback ID defined in the function’s definition file
function_app_id: Option<String>The encoded ID of the app
permission_type: Option<String>The type of permission that defines how the function can be distributed
user_ids: Option<Vec<String>>List of encoded user IDs
team_ids: Option<Vec<String>>List of team IDs to allow for named_entities permission
org_ids: Option<Vec<String>>List of org IDs to allow for named_entities permission
Implementations
Sourceimpl FunctionsDistributionsPermissionsSetRequest
impl FunctionsDistributionsPermissionsSetRequest
pub fn new() -> Self
pub fn function_id(self, function_id: impl Into<String>) -> Self
pub fn function_callback_id( self, function_callback_id: impl Into<String>, ) -> Self
pub fn function_app_id(self, function_app_id: impl Into<String>) -> Self
pub fn permission_type(self, permission_type: impl Into<String>) -> Self
pub fn user_ids(self, user_ids: Vec<String>) -> Self
pub fn team_ids(self, team_ids: Vec<String>) -> Self
pub fn org_ids(self, org_ids: Vec<String>) -> Self