OauthAccessRequest

Struct OauthAccessRequest 

#[non_exhaustive]
pub struct OauthAccessRequest { pub client_id: Option<String>, pub client_secret: Option<String>, pub code: Option<String>, pub redirect_uri: Option<String>, pub single_channel: Option<bool>, }
Arguments for the Slack Web API method oauth.access: Exchanges a temporary OAuth verifier code for an access token.

Send it with SlackClient::oauth_access.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
client_id: Option<String>

Issued when you created your application. If possible, avoid sending client_id and client_secret as parameters in your request and instead supply the Client ID and Client Secret using the HTTP Basic authentication scheme.

client_secret: Option<String>

Issued when you created your application. If possible, avoid sending client_id and client_secret as parameters in your request and instead supply the Client ID and Client Secret using the HTTP Basic authentication scheme.

code: Option<String>

The code param returned via the OAuth callback.

redirect_uri: Option<String>

This must match the originally submitted URI (if one was sent).

single_channel: Option<bool>

Request the user to add your app only to a single channel. Only valid with a legacy workspace app.

Implementations

Source

impl OauthAccessRequest

pub fn new() -> Self

pub fn client_id(self, client_id: impl Into<String>) -> Self

pub fn client_secret(self, client_secret: impl Into<String>) -> Self

pub fn code(self, code: impl Into<String>) -> Self

pub fn redirect_uri(self, redirect_uri: impl Into<String>) -> Self

pub fn single_channel(self, single_channel: bool) -> Self