#[non_exhaustive]pub struct OauthV2UserAccessRequest {
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub code: Option<String>,
pub code_verifier: Option<String>,
pub redirect_uri: Option<String>,
pub grant_type: Option<String>,
pub refresh_token: Option<String>,
pub assertion: Option<String>,
}Expand description
Arguments for the Slack Web API method oauth.v2.user.access: Exchanges a temporary OAuth verifier code for a user access token.
Send it with SlackClient::oauth_v2_user_access.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_id: Option<String>Issued when you created your application. If possible, avoid sending client_id and client_secret as parameters in your request and instead supply the Client ID and Client Secret using the HTTP Basic authentication scheme.
client_secret: Option<String>Issued when you created your application. If possible, avoid sending client_id and client_secret as parameters in your request and instead supply the Client ID and Client Secret using the HTTP Basic authentication scheme.
code: Option<String>The code param returned via the OAuth callback.
code_verifier: Option<String>The code_verifier param used to generate the code_challenge originally. Used for PKCE.
redirect_uri: Option<String>This must match the originally submitted URI (if one was sent).
grant_type: Option<String>The grant_type param as described in the OAuth spec.
refresh_token: Option<String>The refresh_token param as described in the OAuth spec.
assertion: Option<String>Identity assertion JWT authorization grant.