#[non_exhaustive]pub struct ReactionsListRequest {
pub user: Option<String>,
pub full: Option<bool>,
pub count: Option<i64>,
pub page: Option<i64>,
pub cursor: Option<String>,
pub limit: Option<i64>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method reactions.list: Lists reactions made by a user.
Send it with SlackClient::reactions_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user: Option<String>Show reactions made by this user. Defaults to the authed user.
full: Option<bool>If true always return the complete reaction list.
count: Option<i64>page: Option<i64>cursor: Option<String>Parameter for pagination. Set cursor equal to the next_cursor attribute returned by the previous request’s response_metadata. This parameter is optional, but pagination is mandatory: the default value simply fetches the first “page” of the collection. See pagination for more details.
limit: Option<i64>The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn’t been reached.
team_id: Option<String>encoded team id to list reactions in, required if org token is used
Implementations
Sourceimpl ReactionsListRequest
impl ReactionsListRequest
pub fn new() -> Self
pub fn user(self, user: impl Into<String>) -> Self
pub fn full(self, full: bool) -> Self
pub fn count(self, count: i64) -> Self
pub fn page(self, page: i64) -> Self
pub fn cursor(self, cursor: impl Into<String>) -> Self
pub fn limit(self, limit: i64) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self