#[non_exhaustive]pub struct RemindersAddRequest {
pub text: String,
pub time: String,
pub user: Option<String>,
pub team_id: Option<String>,
pub recurrence: Option<Value>,
}Expand description
Arguments for the Slack Web API method reminders.add: Creates a reminder.
Send it with SlackClient::reminders_add.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.text: StringThe content of the reminder
time: StringCan also take a type of integer. When this reminder should happen: the Unix timestamp (up to five years from now), the number of seconds until the reminder (if within 24 hours), or a natural language description (Ex. “in 15 minutes,” or “every Thursday”)
user: Option<String>No longer supported - reminders cannot be set for other users. Previously, was the user who would receive the reminder.
team_id: Option<String>Encoded team id, required if org token is used
recurrence: Option<Value>Specify the repeating behavior of a reminder. Available options: daily, weekly, monthly, or yearly. If weekly, may further specify the days of the week.
Implementations