#[non_exhaustive]pub struct RemindersCompleteRequest {
pub reminder: String,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method reminders.complete: Marks a reminder as complete.
Send it with SlackClient::reminders_complete.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reminder: StringThe ID of the reminder to be marked as complete
team_id: Option<String>Encoded team id, required if org token is used
Implementations