#[non_exhaustive]pub struct RemindersListRequest {
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method reminders.list: Lists all reminders created by or for a given user.
Send it with SlackClient::reminders_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.team_id: Option<String>Encoded team id, required if org token is passed
Implementations