RtmStartRequest

Struct RtmStartRequest 

#[non_exhaustive]
pub struct RtmStartRequest { pub simple_latest: Option<bool>, pub no_unreads: Option<bool>, pub mpim_aware: Option<bool>, pub presence_sub: Option<bool>, pub batch_presence_aware: Option<bool>, pub no_latest: Option<bool>, pub include_locale: Option<bool>, }
Arguments for the Slack Web API method rtm.start: Deprecated: Starts a Real Time Messaging session. Use rtm.connect instead.

Send it with SlackClient::rtm_start.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
simple_latest: Option<bool>

Return timestamp only for latest message object of each channel (improves performance).

no_unreads: Option<bool>

Skip unread counts for each channel (improves performance).

mpim_aware: Option<bool>

Returns MPIMs to the client in the API response.

presence_sub: Option<bool>

Only deliver presence events when requested by subscription. See presence subscriptions.

batch_presence_aware: Option<bool>

Batch presence deliveries via subscription. Enabling changes the shape of presence_change events. See batch presence.

no_latest: Option<bool>

Exclude latest timestamps for channels, groups, mpims, and ims. Automatically sets no_unreads to 1

include_locale: Option<bool>

Set this to true to receive the locale for users and channels. Defaults to false

Implementations

Source

impl RtmStartRequest

pub fn new() -> Self

pub fn simple_latest(self, simple_latest: bool) -> Self

pub fn no_unreads(self, no_unreads: bool) -> Self

pub fn mpim_aware(self, mpim_aware: bool) -> Self

pub fn presence_sub(self, presence_sub: bool) -> Self

pub fn batch_presence_aware(self, batch_presence_aware: bool) -> Self

pub fn no_latest(self, no_latest: bool) -> Self

pub fn include_locale(self, include_locale: bool) -> Self