#[non_exhaustive]pub struct SearchMessagesRequest {
pub query: String,
pub count: Option<i64>,
pub highlight: Option<bool>,
pub page: Option<i64>,
pub cursor: Option<String>,
pub sort: Option<String>,
pub sort_dir: Option<String>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method search.messages: Searches for messages matching a query.
Send it with SlackClient::search_messages.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query: StringSearch query.
count: Option<i64>Pass the number of results you want per “page”. Maximum of 100.
highlight: Option<bool>Pass a value of true to enable query highlight markers (see below).
page: Option<i64>cursor: Option<String>Use this when getting results with cursormark pagination. For first call send * for subsequent calls, send the value of next_cursor returned in the previous call’s results
sort: Option<String>Return matches sorted by either score or timestamp.
sort_dir: Option<String>Change sort direction to ascending (asc) or descending (desc).
team_id: Option<String>encoded team id to search in, required if org token is used
Implementations
Sourceimpl SearchMessagesRequest
impl SearchMessagesRequest
pub fn new(query: impl Into<String>) -> Self
pub fn count(self, count: i64) -> Self
pub fn highlight(self, highlight: bool) -> Self
pub fn page(self, page: i64) -> Self
pub fn cursor(self, cursor: impl Into<String>) -> Self
pub fn sort(self, sort: impl Into<String>) -> Self
pub fn sort_dir(self, sort_dir: impl Into<String>) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self