#[non_exhaustive]pub struct SlackListsCreateRequest {
pub name: String,
pub description_blocks: Option<Vec<Block>>,
pub schema: Option<Vec<Value>>,
pub copy_from_list_id: Option<String>,
pub include_copied_list_records: Option<bool>,
pub todo_mode: Option<bool>,
}Expand description
Arguments for the Slack Web API method slackLists.create: Create a List.
Send it with SlackClient::slack_lists_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the List.
description_blocks: Option<Vec<Block>>A rich text description of the List.
schema: Option<Vec<Value>>Column definition for the List.
copy_from_list_id: Option<String>ID of the List to copy.
include_copied_list_records: Option<bool>Boolean indicating whether to include records when a List is copied.
todo_mode: Option<bool>Boolean indicating whether the List should be used to track todo tasks.
Implementations
Sourceimpl SlackListsCreateRequest
impl SlackListsCreateRequest
pub fn new(name: impl Into<String>) -> Self
pub fn description_blocks(self, description_blocks: Vec<Block>) -> Self
pub fn schema(self, schema: Vec<Value>) -> Self
pub fn copy_from_list_id(self, copy_from_list_id: impl Into<String>) -> Self
pub fn include_copied_list_records( self, include_copied_list_records: bool, ) -> Self
pub fn todo_mode(self, todo_mode: bool) -> Self