#[non_exhaustive]pub struct SlackListsItemsCreateRequest {
pub list_id: String,
pub duplicated_item_id: Option<String>,
pub parent_item_id: Option<String>,
pub initial_fields: Option<Vec<Value>>,
}Expand description
Arguments for the Slack Web API method slackLists.items.create: Add a new item to an existing List.
Send it with SlackClient::slack_lists_items_create.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.list_id: StringID of the List to add the item to.
duplicated_item_id: Option<String>ID of the record to make a copy of.
parent_item_id: Option<String>ID of the parent record for this subtask.
initial_fields: Option<Vec<Value>>Initial item data.
Implementations