#[non_exhaustive]pub struct StarsAddRequest {
pub channel: Option<String>,
pub file: Option<String>,
pub file_comment: Option<String>,
pub timestamp: Option<String>,
}Expand description
Arguments for the Slack Web API method stars.add: Save an item for later. Formerly known as adding a star.
Send it with SlackClient::stars_add.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: Option<String>Channel to add star to, or channel where the message to add star to was posted (used with timestamp).
file: Option<String>File to add star to.
file_comment: Option<String>File comment to add star to.
timestamp: Option<String>Timestamp of the message to add star to.
Implementations