#[non_exhaustive]pub struct StarsListRequest {
pub count: Option<i64>,
pub cursor: Option<String>,
pub limit: Option<i64>,
pub page: Option<i64>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method stars.list: Listed a user’s saved items, formerly known as stars.
Send it with SlackClient::stars_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.count: Option<i64>cursor: Option<String>Parameter for pagination. Set cursor equal to the next_cursor attribute returned by the previous request’s response_metadata. This parameter is optional, but pagination is mandatory: the default value simply fetches the first “page” of the collection. See pagination for more details.
limit: Option<i64>The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn’t been reached.
page: Option<i64>team_id: Option<String>encoded team id to list stars in, required if org token is used
Implementations