#[non_exhaustive]pub struct StarsRemoveRequest {
pub channel: Option<String>,
pub file: Option<String>,
pub file_comment: Option<String>,
pub timestamp: Option<String>,
}Expand description
Arguments for the Slack Web API method stars.remove: Removes a saved item (star) from an item.
Send it with SlackClient::stars_remove.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: Option<String>Channel to remove star from, or channel where the message to remove star from was posted (used with timestamp).
file: Option<String>File to remove star from.
file_comment: Option<String>File comment to remove star from.
timestamp: Option<String>Timestamp of the message to remove star from.
Implementations