#[non_exhaustive]pub struct TeamBillableInfoRequest {
pub cursor: Option<String>,
pub limit: Option<i64>,
pub user: Option<String>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method team.billableInfo: Gets billable users information for the current team.
Send it with SlackClient::team_billable_info.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cursor: Option<String>Set cursor to next_cursor returned by previous call, to indicate from where you want to list next page of users list. Default value fetches the first page.
limit: Option<i64>The maximum number of items to return.
user: Option<String>A user to retrieve the billable information for. Defaults to all users.
team_id: Option<String>encoded team id to get the billable information from, required if org token is used
Implementations