#[non_exhaustive]pub struct TeamInfoRequest {
pub domain: Option<String>,
pub team: Option<String>,
}Expand description
Arguments for the Slack Web API method team.info: Gets information about the current team.
Send it with SlackClient::team_info.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain: Option<String>Query by domain instead of team (only when team is null). This only works for domains in the same enterprise as the querying team token. This also expects the domain to belong to a team and not the enterprise itself. This is the value set up for the ‘Joining This Workspace’ workspace setting. If it contains more than one domain, the field will contain multiple comma-separated domain values. If no domain is set, the field is empty.
team: Option<String>Team to get info about; if omitted, will return information about the current team.
Implementations