#[non_exhaustive]pub struct TeamIntegrationLogsRequest {
pub app_id: Option<String>,
pub change_type: Option<String>,
pub count: Option<String>,
pub page: Option<String>,
pub service_id: Option<String>,
pub team_id: Option<String>,
pub user: Option<String>,
}Expand description
Arguments for the Slack Web API method team.integrationLogs: Gets the integration logs for the current team.
Send it with SlackClient::team_integration_logs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_id: Option<String>Filter logs to this Slack app. Defaults to all logs.
change_type: Option<String>Filter logs with this change type. Possible values are added, removed, enabled, disabled, and updated. Defaults to all logs.
count: Option<String>page: Option<String>service_id: Option<String>Filter logs to this service. Defaults to all logs.
team_id: Option<String>encoded team id to get logs from, required if org token is used
user: Option<String>Filter logs generated by this user’s actions. Defaults to all logs.
Implementations
Sourceimpl TeamIntegrationLogsRequest
impl TeamIntegrationLogsRequest
pub fn new() -> Self
pub fn app_id(self, app_id: impl Into<String>) -> Self
pub fn change_type(self, change_type: impl Into<String>) -> Self
pub fn count(self, count: impl Into<String>) -> Self
pub fn page(self, page: impl Into<String>) -> Self
pub fn service_id(self, service_id: impl Into<String>) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self
pub fn user(self, user: impl Into<String>) -> Self