#[non_exhaustive]pub struct ToolingTokensRotateRequest {
pub refresh_token: String,
}Expand description
Arguments for the Slack Web API method tooling.tokens.rotate: Exchanges a refresh token for a new app configuration token.
Send it with SlackClient::tooling_tokens_rotate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.refresh_token: StringThe xoxe refresh token that was issued along with the old app configuration token.
Implementations