#[non_exhaustive]pub struct UsergroupsEnableRequest {
pub usergroup: String,
pub include_count: Option<bool>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method usergroups.enable: Enable a User Group.
Send it with SlackClient::usergroups_enable.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.usergroup: StringThe encoded ID of the User Group to enable.
include_count: Option<bool>Include the number of users in the User Group.
team_id: Option<String>Encoded team id where the user group is, required if org token is used.
Implementations