#[non_exhaustive]pub struct UsergroupsListRequest {
pub include_count: Option<bool>,
pub include_disabled: Option<bool>,
pub include_users: Option<bool>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method usergroups.list: List all User Groups for a team.
Send it with SlackClient::usergroups_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.include_count: Option<bool>Include the number of users in each User Group.
include_disabled: Option<bool>Include results for disabled User Groups.
include_users: Option<bool>Include the list of users for each User Group.
team_id: Option<String>The user group’s encoded team ID. Required if org token is used.
Implementations
Sourceimpl UsergroupsListRequest
impl UsergroupsListRequest
pub fn new() -> Self
pub fn include_count(self, include_count: bool) -> Self
pub fn include_disabled(self, include_disabled: bool) -> Self
pub fn include_users(self, include_users: bool) -> Self
pub fn team_id(self, team_id: impl Into<String>) -> Self