#[non_exhaustive]pub struct UsergroupsUpdateRequest {
pub usergroup: String,
pub channels: Option<Vec<String>>,
pub additional_channels: Option<Vec<String>>,
pub description: Option<String>,
pub handle: Option<String>,
pub include_count: Option<bool>,
pub name: Option<String>,
pub team_id: Option<String>,
pub enable_section: Option<bool>,
}Expand description
Arguments for the Slack Web API method usergroups.update: Update an existing User Group.
Send it with SlackClient::usergroups_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.usergroup: StringThe encoded ID of the User Group to update.
channels: Option<Vec<String>>A comma separated string of encoded channel IDs for which the User Group uses as a default.
additional_channels: Option<Vec<String>>A comma separated string of encoded channel IDs for which the User Group can custom add usergroup members too.
description: Option<String>A short description of the User Group.
handle: Option<String>A mention handle. Must be unique among channels, users and User Groups.
include_count: Option<bool>Include the number of users in the User Group.
name: Option<String>A name for the User Group. Must be unique among User Groups.
team_id: Option<String>encoded team id where the user group exists, required if org token is used
enable_section: Option<bool>Configure this user group to show as a sidebar section for all group members. Note: Only relevant if group has 1 or more default channels added.