#[non_exhaustive]pub struct UsergroupsUsersUpdateRequest {
pub usergroup: String,
pub users: Vec<String>,
pub include_count: Option<bool>,
pub team_id: Option<String>,
pub additional_channels: Option<Vec<String>>,
pub is_shared: Option<bool>,
}Expand description
Arguments for the Slack Web API method usergroups.users.update: Update the list of users for a user group.
Send it with SlackClient::usergroups_users_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.usergroup: StringThe encoded ID of the user group to update.
users: Vec<String>A comma separated string of encoded user IDs that represent the entire list of users for the user group.
include_count: Option<bool>Include the number of users in the user group.
team_id: Option<String>encoded team id where the user group exists, required if org token is used
additional_channels: Option<Vec<String>>A comma separated string of encoded channel IDs for which the User Group can custom add usergroup members too.
Boolean to identify if the API is getting called when a shared section is getting shared
Implementations