#[non_exhaustive]pub struct UsersListRequest {
pub cursor: Option<String>,
pub include_locale: Option<bool>,
pub limit: Option<i64>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method users.list: Lists all users in a Slack team.
Send it with SlackClient::users_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.
include_locale: Option<bool>Set this to true to receive the locale for users. Defaults to false
limit: Option<i64>The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the users list hasn’t been reached. Providing no limit value will result in Slack attempting to deliver you the entire result set. If the collection is too large you may experience limit_required or HTTP 500 errors.
team_id: Option<String>encoded team id to list users in, required if org token is used