#[non_exhaustive]pub struct ViewsPublishRequest {
pub user_id: String,
pub view: View,
pub hash: Option<String>,
pub interactivity_pointer: Option<String>,
}Expand description
Arguments for the Slack Web API method views.publish: Publish a static view for a User.
Send it with SlackClient::views_publish.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: Stringid of the user you want publish a view to.
view: ViewA view payload. This must be a JSON-encoded string.
hash: Option<String>A string that represents view state to protect against possible race conditions.
interactivity_pointer: Option<String>Implementations