#[non_exhaustive]pub struct ViewsPushRequest {
pub view: View,
pub trigger_id: Option<String>,
pub interactivity_pointer: Option<String>,
}Expand description
Arguments for the Slack Web API method views.push: Push a view onto the stack of a root view.
Send it with SlackClient::views_push.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.view: ViewA view payload. This must be a JSON-encoded string.
trigger_id: Option<String>Exchange a trigger to post to the user.
interactivity_pointer: Option<String>Exchange an interactivity pointer to post to the user.
Implementations