#[non_exhaustive]pub struct ViewsUpdateRequest {
pub view: View,
pub view_id: Option<String>,
pub external_id: Option<String>,
pub hash: Option<String>,
}Expand description
Arguments for the Slack Web API method views.update: Update an existing view.
Send it with SlackClient::views_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.view: ViewA view object. This must be a JSON-encoded string.
view_id: Option<String>A unique identifier of the view to be updated. Either view_id or external_id is required.
external_id: Option<String>A unique identifier of the view set by the developer. Must be unique for all views on a team. Max length of 255 characters. Either view_id or external_id is required.
hash: Option<String>A string that represents view state to protect against possible race conditions.
Implementations