#[non_exhaustive]pub struct WorkflowsTriggersPermissionsListRequest {
pub trigger_id: String,
}Expand description
Arguments for the Slack Web API method workflows.triggers.permissions.list: Returns the permission type of a trigger and if applicable, includes the entities that have been granted access
Send it with SlackClient::workflows_triggers_permissions_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trigger_id: StringEncoded ID of the trigger
Implementations