#[non_exhaustive]pub struct WorkflowsTriggersPermissionsSetRequest {
pub trigger_id: String,
pub permission_type: String,
pub user_ids: Option<Vec<String>>,
pub channel_ids: Option<Vec<String>>,
pub team_ids: Option<Vec<String>>,
pub org_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method workflows.triggers.permissions.set: Set the permission type for who can run a trigger
Send it with SlackClient::workflows_triggers_permissions_set.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trigger_id: StringEncoded ID of the trigger
permission_type: StringThe type of permission that defines who can run a trigger
user_ids: Option<Vec<String>>List of encoded user IDs
channel_ids: Option<Vec<String>>List of encoded channel IDs
team_ids: Option<Vec<String>>List of encoded workspace IDs
org_ids: Option<Vec<String>>List of encoded organization IDs
Implementations
Sourceimpl WorkflowsTriggersPermissionsSetRequest
impl WorkflowsTriggersPermissionsSetRequest
pub fn new( trigger_id: impl Into<String>, permission_type: impl Into<String>, ) -> Self
pub fn user_ids(self, user_ids: Vec<String>) -> Self
pub fn channel_ids(self, channel_ids: Vec<String>) -> Self
pub fn team_ids(self, team_ids: Vec<String>) -> Self
pub fn org_ids(self, org_ids: Vec<String>) -> Self