pub trait NextCursor {
// Required method
fn next_cursor(&self) -> Option<&str>;
}Expand description
A response that carries the cursor for the next page.
Required Methods
Sourcefn next_cursor(&self) -> Option<&str>
fn next_cursor(&self) -> Option<&str>
Cursor for the next page, or None on the last page.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".