#[non_exhaustive]pub struct AdminAppsMcpServersPermissionsSetRequest {
pub app_id: String,
pub server_id: String,
pub permission_type: String,
pub user_ids: Option<Vec<String>>,
pub usergroup_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method admin.apps.mcp.servers.permissions.set: Set the access control permission for who can use an MCP server.
Send it with SlackClient::admin_apps_mcp_servers_permissions_set.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_id: StringEncoded ID of the app
server_id: StringEncoded ID of the MCP server
permission_type: StringThe type of permission that defines who can use this MCP server
user_ids: Option<Vec<String>>List of user IDs to set for named_entities or named_entities_exclude
usergroup_ids: Option<Vec<String>>List of encoded usergroup IDs
Implementations