AdminUsersGetExpirationRequest

Struct AdminUsersGetExpirationRequest 

#[non_exhaustive]
pub struct AdminUsersGetExpirationRequest { pub user_id: String, pub target_team: Option<String>, }
Arguments for the Slack Web API method admin.users.getExpiration: Fetches the expiration timestamp for a guest.

Send it with SlackClient::admin_users_get_expiration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
user_id: String

The ID of the guest user to get the expiration for.

target_team: Option<String>

If an org token is passed in and this team is on the org, it will operate on the workspace level on the specified team. Otherwise it will operate on the org or team in context.

Implementations

Source

impl AdminUsersGetExpirationRequest

pub fn new(user_id: impl Into<String>) -> Self

pub fn target_team(self, target_team: impl Into<String>) -> Self