#[non_exhaustive]pub struct AdminUsersUnsupportedVersionsExportRequest {
pub date_sessions_started: Option<i64>,
pub date_end_of_support: Option<i64>,
}Expand description
Arguments for the Slack Web API method admin.users.unsupportedVersions.export: Ask Slack to send you an export listing all workspace members using unsupported software, presented as a zipped CSV file.
Send it with SlackClient::admin_users_unsupported_versions_export.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.date_sessions_started: Option<i64>Unix timestamp of a date to start looking for user sessions. If not provided will start six months ago.
date_end_of_support: Option<i64>Unix timestamp of the date of past or upcoming end of support cycles. If not provided will include all announced end of support cycles.
Implementations
Sourceimpl AdminUsersUnsupportedVersionsExportRequest
impl AdminUsersUnsupportedVersionsExportRequest
pub fn new() -> Self
pub fn date_sessions_started(self, date_sessions_started: i64) -> Self
pub fn date_end_of_support(self, date_end_of_support: i64) -> Self