#[non_exhaustive]pub struct AppsActivitiesListRequest {Show 13 fields
pub app_id: String,
pub team_id: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i64>,
pub min_log_level: Option<String>,
pub log_event_type: Option<String>,
pub source: Option<String>,
pub component_type: Option<String>,
pub component_id: Option<String>,
pub trace_id: Option<String>,
pub min_date_created: Option<i64>,
pub max_date_created: Option<i64>,
pub sort_direction: Option<String>,
}Expand description
Arguments for the Slack Web API method apps.activities.list: Get logs for a specified app
Send it with SlackClient::apps_activities_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.app_id: StringThe id of the app to get activities from.
team_id: Option<String>The team who owns this log.
cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. See pagination for more detail.
limit: Option<i64>The maximum number of items to return.
min_log_level: Option<String>The minimum log level of the log events to be returned. Defaults to ‘info’. Acceptable values (in order of relative importance from smallest to largest) are (‘trace’, ‘debug’, ‘info’, ‘warn’, ‘error’, ‘fatal’).
log_event_type: Option<String>The event type of log events to be returned.
source: Option<String>The source of log events to be returned. Acceptable values are (‘slack’, ‘developer’).
component_type: Option<String>The component type of log events to be returned. Acceptable values are (‘events_api’, ‘workflows’, ‘functions’, ‘tables’).
component_id: Option<String>The component id of log events to be returned. Will be ‘FnXXXXXX’ for functions, and ‘WfXXXXXX’ for workflows
trace_id: Option<String>The trace id of log events to be returned.
min_date_created: Option<i64>The earliest timestamp of the log to retrieve (epoch microseconds).
max_date_created: Option<i64>The latest timestamp of the log to retrieve (epoch microseconds).
sort_direction: Option<String>The direction you want the data sorted by (always by timestamp)