#[non_exhaustive]pub struct CallsAddRequest {
pub external_unique_id: String,
pub join_url: String,
pub external_display_id: Option<String>,
pub desktop_app_join_url: Option<String>,
pub date_start: Option<i64>,
pub title: Option<String>,
pub created_by: Option<String>,
pub users: Option<Vec<Value>>,
}Expand description
Arguments for the Slack Web API method calls.add: Registers a new Call.
Send it with SlackClient::calls_add.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.external_unique_id: StringAn ID supplied by the 3rd-party Call provider. It must be unique across all Calls from that service.
join_url: StringThe URL required for a client to join the Call.
external_display_id: Option<String>An optional, human-readable ID supplied by the 3rd-party Call provider. If supplied, this ID will be displayed in the Call object.
desktop_app_join_url: Option<String>When supplied, available Slack clients will attempt to directly launch the 3rd-party Call with this URL.
date_start: Option<i64>Unix timestamp of the call start time
title: Option<String>The name of the Call.
created_by: Option<String>The valid Slack user ID of the user who created this Call. When this method is called with a user token, the created_by field is optional and defaults to the authed user of the token. Otherwise, the field is required.
users: Option<Vec<Value>>The list of users to register as participants in the Call. Read more on how to specify users here.