#[non_exhaustive]pub struct ChatPostEphemeralRequest {Show 14 fields
pub channel: String,
pub user: String,
pub as_user: Option<bool>,
pub attachments: Option<Vec<Attachment>>,
pub blocks: Option<Vec<Block>>,
pub icon_emoji: Option<String>,
pub icon_url: Option<String>,
pub link_names: Option<bool>,
pub markdown_text: Option<String>,
pub metadata: Option<MessageMetadata>,
pub parse: Option<String>,
pub text: Option<String>,
pub thread_ts: Option<String>,
pub username: Option<String>,
}Expand description
Arguments for the Slack Web API method chat.postEphemeral: Sends an ephemeral message to a user in a channel.
Send it with SlackClient::chat_post_ephemeral.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel, private group, or IM channel to send message to. Can be an encoded ID, or a name.
user: Stringid of the user who will receive the ephemeral message. The user should be in the channel specified by the channel argument.
as_user: Option<bool>(Legacy) Pass true to post the message as the authed user. Defaults to true if the chat:write:bot scope is not included. Otherwise, defaults to false.
attachments: Option<Vec<Attachment>>A JSON-based array of structured attachments, presented as a URL-encoded string.
blocks: Option<Vec<Block>>A JSON-based array of structured blocks, presented as a URL-encoded string.
icon_emoji: Option<String>Emoji to use as the icon for this message. Overrides icon_url.
icon_url: Option<String>URL to an image to use as the icon for this message.
link_names: Option<bool>Find and link channel names and usernames.
markdown_text: Option<String>Accepts message text formatted in markdown. This argument should not be used in conjunction with blocks or text. Limit this field to 12,000 characters.
metadata: Option<MessageMetadata>JSON object with an entities array of work object entity metadata, presented as a URL-encoded string. Only entity metadata is supported: ephemeral messages are not persisted and never dispatch message_metadata_* events, so event_type/event_payload message metadata is ignored here. Each entity requires entity_type, entity_payload, external_ref, and url.
parse: Option<String>Change how messages are treated. Defaults to none. See below.
text: Option<String>How this field works and whether it is required depends on other fields you use in your API call. See below for more detail.
thread_ts: Option<String>Provide another message’s ts value to post this message in a thread. Avoid using a reply’s ts value; use its parent’s value instead. Ephemeral messages in threads are only shown if there is already an active thread.
username: Option<String>Set your bot’s user name.