#[non_exhaustive]pub struct ChatScheduleMessageRequest {Show 14 fields
pub channel: String,
pub post_at: i64,
pub as_user: Option<bool>,
pub attachments: Option<Vec<Attachment>>,
pub blocks: Option<Vec<Block>>,
pub link_names: Option<bool>,
pub markdown_text: Option<String>,
pub parse: Option<String>,
pub reply_broadcast: Option<bool>,
pub text: Option<String>,
pub thread_ts: Option<String>,
pub unfurl_links: Option<bool>,
pub unfurl_media: Option<bool>,
pub metadata: Option<MessageMetadata>,
}Expand description
Arguments for the Slack Web API method chat.scheduleMessage: Schedules a message to be sent to a channel.
Send it with SlackClient::chat_schedule_message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel, private group, or DM channel to send message to. Can be an encoded ID, or a name. See below for more details.
post_at: i64Unix timestamp representing the future time the message should post to Slack.
as_user: Option<bool>Set to true to post the message as the authed user, instead of as a bot. Defaults to false. Cannot be used by new Slack apps. See chat.postMessage.
attachments: Option<Vec<Attachment>>A JSON-based array of structured attachments, presented as a URL-encoded string.
blocks: Option<Vec<Block>>A JSON-based array of structured blocks, presented as a URL-encoded string.
link_names: Option<bool>Find and link user groups. No longer supports linking individual users; use syntax shown in Mentioning Users instead.
markdown_text: Option<String>Accepts message text formatted in markdown. This argument should not be used in conjunction with blocks or text. Limit this field to 12,000 characters.
parse: Option<String>Change how messages are treated. See chat.postMessage.
reply_broadcast: Option<bool>Used in conjunction with thread_ts and indicates whether reply should be made visible to everyone in the channel or conversation. Defaults to false.
text: Option<String>How this field works and whether it is required depends on other fields you use in your API call. See below for more detail.
thread_ts: Option<String>Provide another message’s ts value to make this message a reply. Avoid using a reply’s ts value; use its parent instead.
unfurl_links: Option<bool>Pass true to enable unfurling of primarily text-based content.
unfurl_media: Option<bool>Pass false to disable unfurling of media content.
metadata: Option<MessageMetadata>JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace.