ChatStopStreamRequest

Struct ChatStopStreamRequest 

#[non_exhaustive]
pub struct ChatStopStreamRequest { pub channel: String, pub ts: String, pub chunks: Option<Vec<Value>>, pub markdown_text: Option<String>, pub blocks: Option<Vec<Block>>, pub metadata: Option<MessageMetadata>, pub session_status: Option<String>, }
Arguments for the Slack Web API method chat.stopStream: Stop a streaming conversation

Send it with SlackClient::chat_stop_stream.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
channel: String

An encoded ID that represents a channel, private group, or DM

ts: String

The timestamp of the streaming message.

chunks: Option<Vec<Value>>

Array of streaming chunks. Can include markdown text chunk objects, task update chunk objects, plan update chunks, or blocks chunks.

markdown_text: Option<String>

Accepts message text formatted in markdown. Limit this field to 12,000 characters.

blocks: Option<Vec<Block>>

A list of blocks that will be rendered at the bottom of the finalized message.

metadata: Option<MessageMetadata>

JSON object with event_type and event_payload fields, presented as a URL-encoded string. Metadata you post to Slack is accessible to any app or user who is a member of that workspace.

session_status: Option<String>

The session status to set after stopping the stream.

Implementations

Source

impl ChatStopStreamRequest

pub fn new(channel: impl Into<String>, ts: impl Into<String>) -> Self

pub fn chunks(self, chunks: Vec<Value>) -> Self

pub fn markdown_text(self, markdown_text: impl Into<String>) -> Self

pub fn blocks(self, blocks: Vec<Block>) -> Self

pub fn metadata(self, metadata: MessageMetadata) -> Self

pub fn session_status(self, session_status: impl Into<String>) -> Self