#[non_exhaustive]pub struct ChatUpdateRequest {Show 13 fields
pub channel: String,
pub ts: String,
pub as_user: Option<bool>,
pub attachments: Option<Vec<Attachment>>,
pub unfurled_attachments: Option<String>,
pub blocks: Option<Vec<Block>>,
pub markdown_text: Option<String>,
pub metadata: Option<MessageMetadata>,
pub link_names: Option<bool>,
pub parse: Option<String>,
pub text: Option<String>,
pub reply_broadcast: Option<bool>,
pub file_ids: Option<Vec<String>>,
}Expand description
Arguments for the Slack Web API method chat.update: Updates a message.
Send it with SlackClient::chat_update.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: StringChannel containing the message to be updated. For direct messages, ensure that this value is a DM ID (starts with D) instead of a User ID (starts with either U or W).
ts: StringTimestamp of the message to be updated.
as_user: Option<bool>Pass true to update the message as the authed user. Bot users in this context are considered authed users.
attachments: Option<Vec<Attachment>>A JSON-based array of structured attachments, presented as a URL-encoded string.
unfurled_attachments: Option<String>A JSON-based array of structured attachments, presented as a URL-encoded string.
blocks: Option<Vec<Block>>A JSON-based array of structured blocks, presented as a URL-encoded string.
markdown_text: Option<String>Accepts message text formatted in markdown. This argument should not be used in conjunction with blocks or text. Limit this field to 12,000 characters.
metadata: Option<MessageMetadata>JSON object with event_type and event_payload fields, presented as a URL-encoded string. If you don’t include this field, the message’s previous metadata will be retained. To remove previous metadata, include an empty object for this field. Metadata you post to Slack is accessible to any app or user who is a member of that workspace.
link_names: Option<bool>Find and link channel names and usernames. Defaults to none. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, none.
parse: Option<String>Change how messages are treated. Defaults to client, unlike chat.postMessage. Accepts either none or full. If you do not specify a value for this field, the original value set for the message will be overwritten with the default, client.
text: Option<String>How this field works and whether it is required depends on other fields you use in your API call. See below for more detail.
reply_broadcast: Option<bool>Broadcast an existing thread reply to make it visible to everyone in the channel or conversation.
file_ids: Option<Vec<String>>Array of new file ids that will be sent with this message.