ConversationsAcceptSharedInviteRequest

Struct ConversationsAcceptSharedInviteRequest 

#[non_exhaustive]
pub struct ConversationsAcceptSharedInviteRequest { pub channel_name: String, pub is_private: Option<bool>, pub free_trial_accepted: Option<bool>, pub invite_id: Option<String>, pub channel_id: Option<String>, pub team_id: Option<String>, }
Arguments for the Slack Web API method conversations.acceptSharedInvite: Accepts an invitation to a Slack Connect channel.

Send it with SlackClient::conversations_accept_shared_invite.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
channel_name: String

Name of the channel. If the channel does not exist already in your workspace, this name is the one that the channel will take.

is_private: Option<bool>

Whether the channel should be private.

free_trial_accepted: Option<bool>

Whether you’d like to use your workspace’s free trial to begin using Slack Connect.

invite_id: Option<String>

ID of the invite that you’d like to accept. Must provide either invite_id or channel_id. See the shared_channel_invite_received event payload for more details on how to retrieve the ID of the invitation.

channel_id: Option<String>

ID of the channel that you’d like to accept. Must provide either invite_id or channel_id.

team_id: Option<String>

The ID of the workspace to accept the channel in. If an org-level token is used to call this method, the team_id argument is required.

Implementations

Source

impl ConversationsAcceptSharedInviteRequest

pub fn new(channel_name: impl Into<String>) -> Self

pub fn is_private(self, is_private: bool) -> Self

pub fn free_trial_accepted(self, free_trial_accepted: bool) -> Self

pub fn invite_id(self, invite_id: impl Into<String>) -> Self

pub fn channel_id(self, channel_id: impl Into<String>) -> Self

pub fn team_id(self, team_id: impl Into<String>) -> Self