#[non_exhaustive]pub struct FilesCompleteUploadExternalRequest {
pub files: Vec<Value>,
pub channel_id: Option<String>,
pub thread_ts: Option<String>,
pub channels: Option<String>,
pub initial_comment: Option<String>,
pub blocks: Option<Vec<Block>>,
pub username: Option<String>,
pub icon_url: Option<String>,
pub icon_emoji: Option<String>,
}Expand description
Arguments for the Slack Web API method files.completeUploadExternal: Finishes an upload started with files.getUploadURLExternal
Send it with SlackClient::files_complete_upload_external.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.files: Vec<Value>Array of file ids and their corresponding (optional) titles.
channel_id: Option<String>Channel ID where the file will be shared. If not specified the file will be private.
thread_ts: Option<String>Provide another message’s ts value to upload this file as a reply. Never use a reply’s ts value; use its parent instead. Also make sure to provide only one channel when using ‘thread_ts’
channels: Option<String>Comma-separated string of channel IDs or user IDs where the file will be shared.
initial_comment: Option<String>The message text introducing the file in specified channels.
blocks: Option<Vec<Block>>A JSON-based array of structured rich text blocks, presented as a URL-encoded string. If the initial_comment field is provided, the blocks field is ignored
username: Option<String>Set your bot’s user name for the file share message. Requires the chat:write.customize scope.
icon_url: Option<String>URL to an image to use as the icon for the file share message. Requires the chat:write.customize scope.
icon_emoji: Option<String>Emoji to use as the icon for the file share message. Overrides icon_url. Requires the chat:write.customize scope.