#[non_exhaustive]pub struct SlackListsItemsListRequest {
pub list_id: String,
pub limit: Option<i64>,
pub cursor: Option<String>,
pub archived: Option<bool>,
pub include_list: Option<bool>,
}Expand description
Arguments for the Slack Web API method slackLists.items.list: Get records from a List.
Send it with SlackClient::slack_lists_items_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.list_id: StringID of the List.
limit: Option<i64>The maximum number of records to return.
cursor: Option<String>Next cursor for pagination.
archived: Option<bool>Boolean indicating whether archived items or normal items should be returned.
include_list: Option<bool>Set to true to also return the parent list object, including its title, column schema, and total row count. Defaults to false to keep the response small.
Implementations