#[non_exhaustive]pub struct TeamAccessLogsRequest {
pub before: Option<String>,
pub count: Option<String>,
pub page: Option<String>,
pub cursor: Option<String>,
pub limit: Option<i64>,
pub team_id: Option<String>,
}Expand description
Arguments for the Slack Web API method team.accessLogs: Gets the access logs for the current team.
Send it with SlackClient::team_access_logs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.before: Option<String>End of time range of logs to include in results (inclusive).
count: Option<String>page: Option<String>cursor: Option<String>Parameter for pagination. Set cursor equal to the next_cursor attribute returned by the previous request’s response_metadata. This parameter is optional, but pagination is mandatory: the default value simply fetches the first “page” of the collection. See pagination for more details.
limit: Option<i64>The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn’t been reached. If specified, result is returned using a cursor-based approach instead of a classic one.
team_id: Option<String>encoded team id to get logs from, required if org token is used