#[non_exhaustive]pub struct TeamExternalTeamsListRequest {
pub limit: Option<i64>,
pub cursor: Option<String>,
pub sort_field: Option<String>,
pub sort_direction: Option<String>,
pub slack_connect_pref_filter: Option<Vec<Value>>,
pub workspace_filter: Option<Vec<Value>>,
pub connection_status_filter: Option<String>,
}Expand description
Arguments for the Slack Web API method team.externalTeams.list: Returns a list of all the external teams connected and details about the connection.
Send it with SlackClient::team_external_teams_list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.limit: Option<i64>The maximum number of items to return per page
cursor: Option<String>Paginate through collections of data by setting parameter to the team_id attribute returned by a previous request’s response_metadata. If not provided, the first page of the collection is returned. See pagination for more detail.
sort_field: Option<String>Name of the parameter that we are sorting by
sort_direction: Option<String>Direction to sort in asc or desc
slack_connect_pref_filter: Option<Vec<Value>>Filters connected orgs by Slack Connect pref override(s). Value can be: approved_orgs_only allow_sc_file_uploads profile_visibility away_team_sc_invite_permissions accept_sc_invites sc_mpdm_to_private require_sc_channel_for_sc_dm external_awareness_context_bar
workspace_filter: Option<Vec<Value>>Shows connected orgs which are connected on a specified encoded workspace ID
connection_status_filter: Option<String>Status of the connected team.