#[non_exhaustive]pub struct UsersConversationsRequest {
pub cursor: Option<String>,
pub exclude_archived: Option<bool>,
pub exclude_muted: Option<bool>,
pub limit: Option<i64>,
pub team_id: Option<String>,
pub types: Option<String>,
pub user: Option<String>,
}Expand description
Arguments for the Slack Web API method users.conversations: List conversations the calling user is a member of.
Send it with SlackClient::users_conversations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cursor: Option<String>Paginate through collections of data by setting the cursor parameter to a next_cursor attribute returned by a previous request’s response_metadata. Default value fetches the first “page” of the collection. See pagination for more detail.
exclude_archived: Option<bool>Set to true to exclude archived channels from the list
exclude_muted: Option<bool>Set to true to exclude muted channels from the list
limit: Option<i64>The maximum number of items to return. Fewer than the requested number of items may be returned, even if the end of the list hasn’t been reached. Must be an integer with a max value of 999.
team_id: Option<String>encoded team id to list conversations in, required if org token is used
types: Option<String>Mix and match channel types by providing a comma-separated list of any combination of public_channel, private_channel, mpim, im
user: Option<String>Browse conversations by a specific user ID’s membership. Non-public channels are restricted to those where the calling user shares membership.